SELECT set_sphere_output_precision(9);

select nside2order(1);
select nside2order(2);
select nside2order(4);
select nside2order(8);
select nside2order(16);
select nside2order(32);
select nside2order(64);
select nside2order(128);
select nside2order(256);
select nside2order(512);
select nside2order(1024);
select nside2order(2048);
select nside2order(4096);
select nside2order(8192);
select nside2order(16384);
select nside2order(32768);
select nside2order(65536);
select nside2order(131072);
select nside2order(262144);
select nside2order(524288);
select nside2order(1048576);
select nside2order(2097152);
select nside2order(4194304);
select nside2order(8388608);
select nside2order(16777216);
select nside2order(33554432);
select nside2order(67108864);
select nside2order(134217728);
select nside2order(268435456);
select nside2order(536870912);
select order2nside(0);
select order2nside(1);
select order2nside(2);
select order2nside(3);
select order2nside(4);
select order2nside(5);
select order2nside(6);
select order2nside(7);
select order2nside(8);
select order2nside(9);
select order2nside(10);
select order2nside(11);
select order2nside(12);
select order2nside(13);
select order2nside(14);
select order2nside(15);
select order2nside(16);
select order2nside(17);
select order2nside(18);
select order2nside(19);
select order2nside(20);
select order2nside(21);
select order2nside(22);
select order2nside(23);
select order2nside(24);
select order2nside(25);
select order2nside(26);
select order2nside(27);
select order2nside(28);
select order2nside(29);
select nside2npix(1);
select nside2npix(2);
select nside2npix(4);
select nside2npix(8);
select nside2npix(16);
select nside2npix(32);
select nside2npix(64);
select nside2npix(128);
select nside2npix(256);
select nside2npix(512);
select nside2npix(1024);
select nside2npix(2048);
select nside2npix(4096);
select nside2npix(8192);
select nside2npix(16384);
select nside2npix(32768);
select nside2npix(65536);
select nside2npix(131072);
select nside2npix(262144);
select nside2npix(524288);
select nside2npix(1048576);
select nside2npix(2097152);
select nside2npix(4194304);
select nside2npix(8388608);
select nside2npix(16777216);
select nside2npix(33554432);
select nside2npix(67108864);
select nside2npix(134217728);
select nside2npix(268435456);
select nside2npix(536870912);
select npix2nside(12);
select npix2nside(48);
select npix2nside(192);
select npix2nside(768);
select npix2nside(3072);
select npix2nside(12288);
select npix2nside(49152);
select npix2nside(196608);
select npix2nside(786432);
select npix2nside(3145728);
select npix2nside(12582912);
select npix2nside(50331648);
select npix2nside(201326592);
select npix2nside(805306368);
select npix2nside(3221225472);
select npix2nside(12884901888);
select npix2nside(51539607552);
select npix2nside(206158430208);
select npix2nside(824633720832);
select npix2nside(3298534883328);
select npix2nside(13194139533312);
select npix2nside(52776558133248);
select npix2nside(211106232532992);
select npix2nside(844424930131968);
select npix2nside(3377699720527872);
select npix2nside(13510798882111488);
select npix2nside(54043195528445952);
select npix2nside(216172782113783808);
select npix2nside(864691128455135232);
select npix2nside(3458764513820540928);

select healpix_nest(0, '(0d, -90d)');
select healpix_ring(0, '(0d, -45d)');
select healpix_ring(0, '(0d, 0.0001)');
select healpix_ring(0, '(0d, 45d)');
select healpix_ring(0, '(0d, 90d)');
select healpix_ring(0, '(90d, -90d)');
select healpix_ring(0, '(90d, -45d)');
select healpix_ring(0, '(90d, 0.0001)');
select healpix_ring(0, '(90d, 45d)');
select healpix_nest(0, '(90d, 90d)');
select healpix_nest(0, '(180d, -90d)');
select healpix_ring(0, '(180d, -45d)');
select healpix_ring(0, '(180d, 0.0001)');
select healpix_nest(0, '(180d, 45d)');
select healpix_nest(0, '(180d, 90d)');
select healpix_nest(0, '(270d, -90d)');
select healpix_nest(0, '(270d, -45d)');
select healpix_ring(0, '(270d, 0.0001)');
select healpix_nest(0, '(270d, 45d)');
select healpix_nest(0, '(270d, 90d)');
select healpix_nest(0, '(360d, -90d)');
select healpix_ring(0, '(360d, -45d)');
select healpix_nest(0, '(360d, 0.0001)');
select healpix_nest(0, '(360d, 45d)');
select healpix_ring(0, '(360d, 90d)');
select healpix_nest(5, '(0d, -90d)');
select healpix_ring(5, '(0d, -67.5d)');
select healpix_nest(5, '(0d, -45d)');
select healpix_nest(5, '(0d, -22.5d)');
select healpix_nest(5, '(0d, 0.0001)');
select healpix_nest(5, '(0d, 22.5d)');
select healpix_ring(5, '(0d, 45d)');
select healpix_ring(5, '(0d, 67.5d)');
select healpix_ring(5, '(0d, 90d)');
select healpix_nest(5, '(45d, -90d)');
select healpix_nest(5, '(45d, -67.5d)');
select healpix_nest(5, '(45d, -45d)');
select healpix_ring(5, '(45d, -22.5d)');
select healpix_ring(5, '(45d, 0.0001)');
select healpix_nest(5, '(45d, 22.5d)');
select healpix_nest(5, '(45d, 45d)');
select healpix_ring(5, '(45d, 67.5d)');
select healpix_nest(5, '(45d, 90d)');
select healpix_ring(5, '(90d, -90d)');
select healpix_nest(5, '(90d, -67.5d)');
select healpix_nest(5, '(90d, -45d)');
select healpix_ring(5, '(90d, -22.5d)');
select healpix_ring(5, '(90d, 0.0001)');
select healpix_ring(5, '(90d, 22.5d)');
select healpix_ring(5, '(90d, 45d)');
select healpix_nest(5, '(90d, 67.5d)');
select healpix_nest(5, '(90d, 90d)');
select healpix_ring(5, '(135d, -90d)');
select healpix_ring(5, '(135d, -67.5d)');
select healpix_nest(5, '(135d, -45d)');
select healpix_nest(5, '(135d, -22.5d)');
select healpix_nest(5, '(135d, 0.0001)');
select healpix_ring(5, '(135d, 22.5d)');
select healpix_nest(5, '(135d, 45d)');
select healpix_ring(5, '(135d, 67.5d)');
select healpix_ring(5, '(135d, 90d)');
select healpix_ring(5, '(180d, -90d)');
select healpix_nest(5, '(180d, -67.5d)');
select healpix_nest(5, '(180d, -45d)');
select healpix_ring(5, '(180d, -22.5d)');
select healpix_ring(5, '(180d, 0.0001)');
select healpix_nest(5, '(180d, 22.5d)');
select healpix_ring(5, '(180d, 45d)');
select healpix_ring(5, '(180d, 67.5d)');
select healpix_ring(5, '(180d, 90d)');
select healpix_nest(5, '(225d, -90d)');
select healpix_ring(5, '(225d, -67.5d)');
select healpix_ring(5, '(225d, -45d)');
select healpix_nest(5, '(225d, -22.5d)');
select healpix_nest(5, '(225d, 0.0001)');
select healpix_nest(5, '(225d, 22.5d)');
select healpix_nest(5, '(225d, 45d)');
select healpix_ring(5, '(225d, 67.5d)');
select healpix_ring(5, '(225d, 90d)');
select healpix_ring(5, '(270d, -90d)');
select healpix_ring(5, '(270d, -67.5d)');
select healpix_ring(5, '(270d, -45d)');
select healpix_nest(5, '(270d, -22.5d)');
select healpix_nest(5, '(270d, 0.0001)');
select healpix_nest(5, '(270d, 22.5d)');
select healpix_ring(5, '(270d, 45d)');
select healpix_ring(5, '(270d, 67.5d)');
select healpix_ring(5, '(270d, 90d)');
select healpix_ring(5, '(315d, -90d)');
select healpix_nest(5, '(315d, -67.5d)');
select healpix_ring(5, '(315d, -45d)');
select healpix_nest(5, '(315d, -22.5d)');
select healpix_nest(5, '(315d, 0.0001)');
select healpix_nest(5, '(315d, 22.5d)');
select healpix_nest(5, '(315d, 45d)');
select healpix_ring(5, '(315d, 67.5d)');
select healpix_ring(5, '(315d, 90d)');
select healpix_nest(5, '(360d, -90d)');
select healpix_nest(5, '(360d, -67.5d)');
select healpix_nest(5, '(360d, -45d)');
select healpix_ring(5, '(360d, -22.5d)');
select healpix_nest(5, '(360d, 0.0001)');
select healpix_ring(5, '(360d, 22.5d)');
select healpix_nest(5, '(360d, 45d)');
select healpix_nest(5, '(360d, 67.5d)');
select healpix_nest(5, '(360d, 90d)');
select healpix_ring(10, '(0d, -90d)');
select healpix_ring(10, '(0d, -78.75d)');
select healpix_ring(10, '(0d, -67.5d)');
select healpix_nest(10, '(0d, -56.25d)');
select healpix_nest(10, '(0d, -45d)');
select healpix_nest(10, '(0d, -33.75d)');
select healpix_ring(10, '(0d, -22.5d)');
select healpix_nest(10, '(0d, -11.25d)');
select healpix_ring(10, '(0d, 0.0001)');
select healpix_nest(10, '(0d, 11.25d)');
select healpix_ring(10, '(0d, 22.5d)');
select healpix_ring(10, '(0d, 33.75d)');
select healpix_ring(10, '(0d, 45d)');
select healpix_ring(10, '(0d, 56.25d)');
select healpix_nest(10, '(0d, 67.5d)');
select healpix_nest(10, '(0d, 78.75d)');
select healpix_nest(10, '(0d, 90d)');
select healpix_nest(10, '(22.5d, -90d)');
select healpix_nest(10, '(22.5d, -78.75d)');
select healpix_nest(10, '(22.5d, -67.5d)');
select healpix_ring(10, '(22.5d, -56.25d)');
select healpix_nest(10, '(22.5d, -45d)');
select healpix_nest(10, '(22.5d, -33.75d)');
select healpix_nest(10, '(22.5d, -22.5d)');
select healpix_ring(10, '(22.5d, -11.25d)');
select healpix_nest(10, '(22.5d, 0.0001)');
select healpix_ring(10, '(22.5d, 11.25d)');
select healpix_ring(10, '(22.5d, 22.5d)');
select healpix_ring(10, '(22.5d, 33.75d)');
select healpix_nest(10, '(22.5d, 45d)');
select healpix_ring(10, '(22.5d, 56.25d)');
select healpix_ring(10, '(22.5d, 67.5d)');
select healpix_nest(10, '(22.5d, 78.75d)');
select healpix_nest(10, '(22.5d, 90d)');
select healpix_nest(10, '(45d, -90d)');
select healpix_ring(10, '(45d, -78.75d)');
select healpix_nest(10, '(45d, -67.5d)');
select healpix_ring(10, '(45d, -56.25d)');
select healpix_nest(10, '(45d, -45d)');
select healpix_ring(10, '(45d, -33.75d)');
select healpix_nest(10, '(45d, -22.5d)');
select healpix_nest(10, '(45d, -11.25d)');
select healpix_nest(10, '(45d, 0.0001)');
select healpix_nest(10, '(45d, 11.25d)');
select healpix_nest(10, '(45d, 22.5d)');
select healpix_nest(10, '(45d, 33.75d)');
select healpix_nest(10, '(45d, 45d)');
select healpix_nest(10, '(45d, 56.25d)');
select healpix_ring(10, '(45d, 67.5d)');
select healpix_ring(10, '(45d, 78.75d)');
select healpix_ring(10, '(45d, 90d)');
select healpix_nest(10, '(67.5d, -90d)');
select healpix_nest(10, '(67.5d, -78.75d)');
select healpix_nest(10, '(67.5d, -67.5d)');
select healpix_nest(10, '(67.5d, -56.25d)');
select healpix_nest(10, '(67.5d, -45d)');
select healpix_nest(10, '(67.5d, -33.75d)');
select healpix_nest(10, '(67.5d, -22.5d)');
select healpix_nest(10, '(67.5d, -11.25d)');
select healpix_ring(10, '(67.5d, 0.0001)');
select healpix_ring(10, '(67.5d, 11.25d)');
select healpix_ring(10, '(67.5d, 22.5d)');
select healpix_nest(10, '(67.5d, 33.75d)');
select healpix_nest(10, '(67.5d, 45d)');
select healpix_ring(10, '(67.5d, 56.25d)');
select healpix_nest(10, '(67.5d, 67.5d)');
select healpix_nest(10, '(67.5d, 78.75d)');
select healpix_nest(10, '(67.5d, 90d)');
select healpix_nest(10, '(90d, -90d)');
select healpix_nest(10, '(90d, -78.75d)');
select healpix_ring(10, '(90d, -67.5d)');
select healpix_ring(10, '(90d, -56.25d)');
select healpix_nest(10, '(90d, -45d)');
select healpix_ring(10, '(90d, -33.75d)');
select healpix_ring(10, '(90d, -22.5d)');
select healpix_nest(10, '(90d, -11.25d)');
select healpix_nest(10, '(90d, 0.0001)');
select healpix_ring(10, '(90d, 11.25d)');
select healpix_nest(10, '(90d, 22.5d)');
select healpix_ring(10, '(90d, 33.75d)');
select healpix_nest(10, '(90d, 45d)');
select healpix_nest(10, '(90d, 56.25d)');
select healpix_nest(10, '(90d, 67.5d)');
select healpix_ring(10, '(90d, 78.75d)');
select healpix_nest(10, '(90d, 90d)');
select healpix_nest(10, '(112.5d, -90d)');
select healpix_nest(10, '(112.5d, -78.75d)');
select healpix_ring(10, '(112.5d, -67.5d)');
select healpix_ring(10, '(112.5d, -56.25d)');
select healpix_ring(10, '(112.5d, -45d)');
select healpix_ring(10, '(112.5d, -33.75d)');
select healpix_ring(10, '(112.5d, -22.5d)');
select healpix_nest(10, '(112.5d, -11.25d)');
select healpix_nest(10, '(112.5d, 0.0001)');
select healpix_nest(10, '(112.5d, 11.25d)');
select healpix_ring(10, '(112.5d, 22.5d)');
select healpix_nest(10, '(112.5d, 33.75d)');
select healpix_nest(10, '(112.5d, 45d)');
select healpix_ring(10, '(112.5d, 56.25d)');
select healpix_ring(10, '(112.5d, 67.5d)');
select healpix_nest(10, '(112.5d, 78.75d)');
select healpix_ring(10, '(112.5d, 90d)');
select healpix_nest(10, '(135d, -90d)');
select healpix_ring(10, '(135d, -78.75d)');
select healpix_ring(10, '(135d, -67.5d)');
select healpix_nest(10, '(135d, -56.25d)');
select healpix_ring(10, '(135d, -45d)');
select healpix_ring(10, '(135d, -33.75d)');
select healpix_nest(10, '(135d, -22.5d)');
select healpix_nest(10, '(135d, -11.25d)');
select healpix_nest(10, '(135d, 0.0001)');
select healpix_nest(10, '(135d, 11.25d)');
select healpix_nest(10, '(135d, 22.5d)');
select healpix_ring(10, '(135d, 33.75d)');
select healpix_ring(10, '(135d, 45d)');
select healpix_ring(10, '(135d, 56.25d)');
select healpix_nest(10, '(135d, 67.5d)');
select healpix_ring(10, '(135d, 78.75d)');
select healpix_ring(10, '(135d, 90d)');
select healpix_ring(10, '(157.5d, -90d)');
select healpix_nest(10, '(157.5d, -78.75d)');
select healpix_ring(10, '(157.5d, -67.5d)');
select healpix_ring(10, '(157.5d, -56.25d)');
select healpix_nest(10, '(157.5d, -45d)');
select healpix_nest(10, '(157.5d, -33.75d)');
select healpix_ring(10, '(157.5d, -22.5d)');
select healpix_nest(10, '(157.5d, -11.25d)');
select healpix_nest(10, '(157.5d, 0.0001)');
select healpix_ring(10, '(157.5d, 11.25d)');
select healpix_ring(10, '(157.5d, 22.5d)');
select healpix_nest(10, '(157.5d, 33.75d)');
select healpix_nest(10, '(157.5d, 45d)');
select healpix_ring(10, '(157.5d, 56.25d)');
select healpix_ring(10, '(157.5d, 67.5d)');
select healpix_nest(10, '(157.5d, 78.75d)');
select healpix_ring(10, '(157.5d, 90d)');
select healpix_nest(10, '(180d, -90d)');
select healpix_ring(10, '(180d, -78.75d)');
select healpix_nest(10, '(180d, -67.5d)');
select healpix_ring(10, '(180d, -56.25d)');
select healpix_ring(10, '(180d, -45d)');
select healpix_ring(10, '(180d, -33.75d)');
select healpix_nest(10, '(180d, -22.5d)');
select healpix_ring(10, '(180d, -11.25d)');
select healpix_nest(10, '(180d, 0.0001)');
select healpix_nest(10, '(180d, 11.25d)');
select healpix_ring(10, '(180d, 22.5d)');
select healpix_nest(10, '(180d, 33.75d)');
select healpix_nest(10, '(180d, 45d)');
select healpix_nest(10, '(180d, 56.25d)');
select healpix_ring(10, '(180d, 67.5d)');
select healpix_ring(10, '(180d, 78.75d)');
select healpix_nest(10, '(180d, 90d)');
select healpix_nest(10, '(202.5d, -90d)');
select healpix_ring(10, '(202.5d, -78.75d)');
select healpix_nest(10, '(202.5d, -67.5d)');
select healpix_nest(10, '(202.5d, -56.25d)');
select healpix_nest(10, '(202.5d, -45d)');
select healpix_nest(10, '(202.5d, -33.75d)');
select healpix_nest(10, '(202.5d, -22.5d)');
select healpix_nest(10, '(202.5d, -11.25d)');
select healpix_nest(10, '(202.5d, 0.0001)');
select healpix_ring(10, '(202.5d, 11.25d)');
select healpix_ring(10, '(202.5d, 22.5d)');
select healpix_ring(10, '(202.5d, 33.75d)');
select healpix_nest(10, '(202.5d, 45d)');
select healpix_nest(10, '(202.5d, 56.25d)');
select healpix_nest(10, '(202.5d, 67.5d)');
select healpix_nest(10, '(202.5d, 78.75d)');
select healpix_nest(10, '(202.5d, 90d)');
select healpix_ring(10, '(225d, -90d)');
select healpix_nest(10, '(225d, -78.75d)');
select healpix_nest(10, '(225d, -67.5d)');
select healpix_nest(10, '(225d, -56.25d)');
select healpix_ring(10, '(225d, -45d)');
select healpix_nest(10, '(225d, -33.75d)');
select healpix_ring(10, '(225d, -22.5d)');
select healpix_ring(10, '(225d, -11.25d)');
select healpix_ring(10, '(225d, 0.0001)');
select healpix_ring(10, '(225d, 11.25d)');
select healpix_nest(10, '(225d, 22.5d)');
select healpix_nest(10, '(225d, 33.75d)');
select healpix_nest(10, '(225d, 45d)');
select healpix_nest(10, '(225d, 56.25d)');
select healpix_nest(10, '(225d, 67.5d)');
select healpix_nest(10, '(225d, 78.75d)');
select healpix_ring(10, '(225d, 90d)');
select healpix_nest(10, '(247.5d, -90d)');
select healpix_ring(10, '(247.5d, -78.75d)');
select healpix_ring(10, '(247.5d, -67.5d)');
select healpix_ring(10, '(247.5d, -56.25d)');
select healpix_ring(10, '(247.5d, -45d)');
select healpix_ring(10, '(247.5d, -33.75d)');
select healpix_nest(10, '(247.5d, -22.5d)');
select healpix_ring(10, '(247.5d, -11.25d)');
select healpix_nest(10, '(247.5d, 0.0001)');
select healpix_nest(10, '(247.5d, 11.25d)');
select healpix_nest(10, '(247.5d, 22.5d)');
select healpix_nest(10, '(247.5d, 33.75d)');
select healpix_nest(10, '(247.5d, 45d)');
select healpix_nest(10, '(247.5d, 56.25d)');
select healpix_nest(10, '(247.5d, 67.5d)');
select healpix_ring(10, '(247.5d, 78.75d)');
select healpix_nest(10, '(247.5d, 90d)');
select healpix_nest(10, '(270d, -90d)');
select healpix_ring(10, '(270d, -78.75d)');
select healpix_ring(10, '(270d, -67.5d)');
select healpix_ring(10, '(270d, -56.25d)');
select healpix_nest(10, '(270d, -45d)');
select healpix_ring(10, '(270d, -33.75d)');
select healpix_nest(10, '(270d, -22.5d)');
select healpix_nest(10, '(270d, -11.25d)');
select healpix_nest(10, '(270d, 0.0001)');
select healpix_nest(10, '(270d, 11.25d)');
select healpix_nest(10, '(270d, 22.5d)');
select healpix_ring(10, '(270d, 33.75d)');
select healpix_ring(10, '(270d, 45d)');
select healpix_ring(10, '(270d, 56.25d)');
select healpix_ring(10, '(270d, 67.5d)');
select healpix_ring(10, '(270d, 78.75d)');
select healpix_nest(10, '(270d, 90d)');
select healpix_nest(10, '(292.5d, -90d)');
select healpix_ring(10, '(292.5d, -78.75d)');
select healpix_nest(10, '(292.5d, -67.5d)');
select healpix_nest(10, '(292.5d, -56.25d)');
select healpix_ring(10, '(292.5d, -45d)');
select healpix_ring(10, '(292.5d, -33.75d)');
select healpix_ring(10, '(292.5d, -22.5d)');
select healpix_ring(10, '(292.5d, -11.25d)');
select healpix_nest(10, '(292.5d, 0.0001)');
select healpix_ring(10, '(292.5d, 11.25d)');
select healpix_ring(10, '(292.5d, 22.5d)');
select healpix_nest(10, '(292.5d, 33.75d)');
select healpix_nest(10, '(292.5d, 45d)');
select healpix_nest(10, '(292.5d, 56.25d)');
select healpix_ring(10, '(292.5d, 67.5d)');
select healpix_nest(10, '(292.5d, 78.75d)');
select healpix_ring(10, '(292.5d, 90d)');
select healpix_nest(10, '(315d, -90d)');
select healpix_nest(10, '(315d, -78.75d)');
select healpix_ring(10, '(315d, -67.5d)');
select healpix_ring(10, '(315d, -56.25d)');
select healpix_nest(10, '(315d, -45d)');
select healpix_ring(10, '(315d, -33.75d)');
select healpix_nest(10, '(315d, -22.5d)');
select healpix_ring(10, '(315d, -11.25d)');
select healpix_nest(10, '(315d, 0.0001)');
select healpix_nest(10, '(315d, 11.25d)');
select healpix_ring(10, '(315d, 22.5d)');
select healpix_ring(10, '(315d, 33.75d)');
select healpix_nest(10, '(315d, 45d)');
select healpix_nest(10, '(315d, 56.25d)');
select healpix_ring(10, '(315d, 67.5d)');
select healpix_ring(10, '(315d, 78.75d)');
select healpix_ring(10, '(315d, 90d)');
select healpix_nest(10, '(337.5d, -90d)');
select healpix_ring(10, '(337.5d, -78.75d)');
select healpix_nest(10, '(337.5d, -67.5d)');
select healpix_ring(10, '(337.5d, -56.25d)');
select healpix_nest(10, '(337.5d, -45d)');
select healpix_ring(10, '(337.5d, -33.75d)');
select healpix_nest(10, '(337.5d, -22.5d)');
select healpix_ring(10, '(337.5d, -11.25d)');
select healpix_nest(10, '(337.5d, 0.0001)');
select healpix_ring(10, '(337.5d, 11.25d)');
select healpix_ring(10, '(337.5d, 22.5d)');
select healpix_nest(10, '(337.5d, 33.75d)');
select healpix_nest(10, '(337.5d, 45d)');
select healpix_ring(10, '(337.5d, 56.25d)');
select healpix_ring(10, '(337.5d, 67.5d)');
select healpix_ring(10, '(337.5d, 78.75d)');
select healpix_ring(10, '(337.5d, 90d)');
select healpix_nest(10, '(360d, -90d)');
select healpix_nest(10, '(360d, -78.75d)');
select healpix_ring(10, '(360d, -67.5d)');
select healpix_ring(10, '(360d, -56.25d)');
select healpix_ring(10, '(360d, -45d)');
select healpix_ring(10, '(360d, -33.75d)');
select healpix_nest(10, '(360d, -22.5d)');
select healpix_ring(10, '(360d, -11.25d)');
select healpix_nest(10, '(360d, 0.0001)');
select healpix_nest(10, '(360d, 11.25d)');
select healpix_nest(10, '(360d, 22.5d)');
select healpix_ring(10, '(360d, 33.75d)');
select healpix_nest(10, '(360d, 45d)');
select healpix_nest(10, '(360d, 56.25d)');
select healpix_ring(10, '(360d, 67.5d)');
select healpix_ring(10, '(360d, 78.75d)');
select healpix_nest(10, '(360d, 90d)');
select healpix_ring(15, '(0d, -90d)');
select healpix_ring(15, '(0d, -84.375d)');
select healpix_nest(15, '(0d, -78.75d)');
select healpix_nest(15, '(0d, -73.125d)');
select healpix_nest(15, '(0d, -67.5d)');
select healpix_nest(15, '(0d, -61.875d)');
select healpix_nest(15, '(0d, -56.25d)');
select healpix_ring(15, '(0d, -50.625d)');
select healpix_ring(15, '(0d, -45d)');
select healpix_ring(15, '(0d, -39.375d)');
select healpix_nest(15, '(0d, -33.75d)');
select healpix_nest(15, '(0d, -28.125d)');
select healpix_ring(15, '(0d, -22.5d)');
select healpix_ring(15, '(0d, -16.875d)');
select healpix_nest(15, '(0d, -11.25d)');
select healpix_nest(15, '(0d, -5.625d)');
select healpix_ring(15, '(0d, 0.0001)');
select healpix_ring(15, '(0d, 5.625d)');
select healpix_ring(15, '(0d, 11.25d)');
select healpix_ring(15, '(0d, 16.875d)');
select healpix_ring(15, '(0d, 22.5d)');
select healpix_nest(15, '(0d, 28.125d)');
select healpix_nest(15, '(0d, 33.75d)');
select healpix_nest(15, '(0d, 39.375d)');
select healpix_nest(15, '(0d, 45d)');
select healpix_nest(15, '(0d, 50.625d)');
select healpix_nest(15, '(0d, 56.25d)');
select healpix_nest(15, '(0d, 61.875d)');
select healpix_nest(15, '(0d, 67.5d)');
select healpix_ring(15, '(0d, 73.125d)');
select healpix_ring(15, '(0d, 78.75d)');
select healpix_nest(15, '(0d, 84.375d)');
select healpix_nest(15, '(0d, 90d)');
select healpix_ring(15, '(11.25d, -90d)');
select healpix_ring(15, '(11.25d, -84.375d)');
select healpix_ring(15, '(11.25d, -78.75d)');
select healpix_nest(15, '(11.25d, -73.125d)');
select healpix_ring(15, '(11.25d, -67.5d)');
select healpix_ring(15, '(11.25d, -61.875d)');
select healpix_nest(15, '(11.25d, -56.25d)');
select healpix_ring(15, '(11.25d, -50.625d)');
select healpix_nest(15, '(11.25d, -45d)');
select healpix_nest(15, '(11.25d, -39.375d)');
select healpix_ring(15, '(11.25d, -33.75d)');
select healpix_ring(15, '(11.25d, -28.125d)');
select healpix_nest(15, '(11.25d, -22.5d)');
select healpix_ring(15, '(11.25d, -16.875d)');
select healpix_ring(15, '(11.25d, -11.25d)');
select healpix_ring(15, '(11.25d, -5.625d)');
select healpix_ring(15, '(11.25d, 0.0001)');
select healpix_nest(15, '(11.25d, 5.625d)');
select healpix_ring(15, '(11.25d, 11.25d)');
select healpix_ring(15, '(11.25d, 16.875d)');
select healpix_ring(15, '(11.25d, 22.5d)');
select healpix_nest(15, '(11.25d, 28.125d)');
select healpix_nest(15, '(11.25d, 33.75d)');
select healpix_nest(15, '(11.25d, 39.375d)');
select healpix_ring(15, '(11.25d, 45d)');
select healpix_ring(15, '(11.25d, 50.625d)');
select healpix_ring(15, '(11.25d, 56.25d)');
select healpix_ring(15, '(11.25d, 61.875d)');
select healpix_ring(15, '(11.25d, 67.5d)');
select healpix_ring(15, '(11.25d, 73.125d)');
select healpix_nest(15, '(11.25d, 78.75d)');
select healpix_nest(15, '(11.25d, 84.375d)');
select healpix_ring(15, '(11.25d, 90d)');
select healpix_nest(15, '(22.5d, -90d)');
select healpix_nest(15, '(22.5d, -84.375d)');
select healpix_ring(15, '(22.5d, -78.75d)');
select healpix_nest(15, '(22.5d, -73.125d)');
select healpix_nest(15, '(22.5d, -67.5d)');
select healpix_ring(15, '(22.5d, -61.875d)');
select healpix_nest(15, '(22.5d, -56.25d)');
select healpix_ring(15, '(22.5d, -50.625d)');
select healpix_nest(15, '(22.5d, -45d)');
select healpix_nest(15, '(22.5d, -39.375d)');
select healpix_nest(15, '(22.5d, -33.75d)');
select healpix_nest(15, '(22.5d, -28.125d)');
select healpix_ring(15, '(22.5d, -22.5d)');
select healpix_ring(15, '(22.5d, -16.875d)');
select healpix_ring(15, '(22.5d, -11.25d)');
select healpix_ring(15, '(22.5d, -5.625d)');
select healpix_ring(15, '(22.5d, 0.0001)');
select healpix_ring(15, '(22.5d, 5.625d)');
select healpix_ring(15, '(22.5d, 11.25d)');
select healpix_ring(15, '(22.5d, 16.875d)');
select healpix_ring(15, '(22.5d, 22.5d)');
select healpix_nest(15, '(22.5d, 28.125d)');
select healpix_ring(15, '(22.5d, 33.75d)');
select healpix_ring(15, '(22.5d, 39.375d)');
select healpix_nest(15, '(22.5d, 45d)');
select healpix_nest(15, '(22.5d, 50.625d)');
select healpix_ring(15, '(22.5d, 56.25d)');
select healpix_ring(15, '(22.5d, 61.875d)');
select healpix_ring(15, '(22.5d, 67.5d)');
select healpix_nest(15, '(22.5d, 73.125d)');
select healpix_ring(15, '(22.5d, 78.75d)');
select healpix_ring(15, '(22.5d, 84.375d)');
select healpix_ring(15, '(22.5d, 90d)');
select healpix_nest(15, '(33.75d, -90d)');
select healpix_nest(15, '(33.75d, -84.375d)');
select healpix_ring(15, '(33.75d, -78.75d)');
select healpix_ring(15, '(33.75d, -73.125d)');
select healpix_nest(15, '(33.75d, -67.5d)');
select healpix_ring(15, '(33.75d, -61.875d)');
select healpix_nest(15, '(33.75d, -56.25d)');
select healpix_nest(15, '(33.75d, -50.625d)');
select healpix_nest(15, '(33.75d, -45d)');
select healpix_nest(15, '(33.75d, -39.375d)');
select healpix_nest(15, '(33.75d, -33.75d)');
select healpix_ring(15, '(33.75d, -28.125d)');
select healpix_ring(15, '(33.75d, -22.5d)');
select healpix_nest(15, '(33.75d, -16.875d)');
select healpix_nest(15, '(33.75d, -11.25d)');
select healpix_ring(15, '(33.75d, -5.625d)');
select healpix_nest(15, '(33.75d, 0.0001)');
select healpix_nest(15, '(33.75d, 5.625d)');
select healpix_ring(15, '(33.75d, 11.25d)');
select healpix_nest(15, '(33.75d, 16.875d)');
select healpix_ring(15, '(33.75d, 22.5d)');
select healpix_ring(15, '(33.75d, 28.125d)');
select healpix_ring(15, '(33.75d, 33.75d)');
select healpix_nest(15, '(33.75d, 39.375d)');
select healpix_ring(15, '(33.75d, 45d)');
select healpix_ring(15, '(33.75d, 50.625d)');
select healpix_nest(15, '(33.75d, 56.25d)');
select healpix_ring(15, '(33.75d, 61.875d)');
select healpix_ring(15, '(33.75d, 67.5d)');
select healpix_ring(15, '(33.75d, 73.125d)');
select healpix_nest(15, '(33.75d, 78.75d)');
select healpix_ring(15, '(33.75d, 84.375d)');
select healpix_nest(15, '(33.75d, 90d)');
select healpix_ring(15, '(45d, -90d)');
select healpix_nest(15, '(45d, -84.375d)');
select healpix_nest(15, '(45d, -78.75d)');
select healpix_nest(15, '(45d, -73.125d)');
select healpix_ring(15, '(45d, -67.5d)');
select healpix_nest(15, '(45d, -61.875d)');
select healpix_ring(15, '(45d, -56.25d)');
select healpix_nest(15, '(45d, -50.625d)');
select healpix_nest(15, '(45d, -45d)');
select healpix_nest(15, '(45d, -39.375d)');
select healpix_ring(15, '(45d, -33.75d)');
select healpix_ring(15, '(45d, -28.125d)');
select healpix_ring(15, '(45d, -22.5d)');
select healpix_nest(15, '(45d, -16.875d)');
select healpix_ring(15, '(45d, -11.25d)');
select healpix_nest(15, '(45d, -5.625d)');
select healpix_ring(15, '(45d, 0.0001)');
select healpix_nest(15, '(45d, 5.625d)');
select healpix_ring(15, '(45d, 11.25d)');
select healpix_nest(15, '(45d, 16.875d)');
select healpix_ring(15, '(45d, 22.5d)');
select healpix_nest(15, '(45d, 28.125d)');
select healpix_ring(15, '(45d, 33.75d)');
select healpix_nest(15, '(45d, 39.375d)');
select healpix_ring(15, '(45d, 45d)');
select healpix_ring(15, '(45d, 50.625d)');
select healpix_nest(15, '(45d, 56.25d)');
select healpix_ring(15, '(45d, 61.875d)');
select healpix_ring(15, '(45d, 67.5d)');
select healpix_nest(15, '(45d, 73.125d)');
select healpix_ring(15, '(45d, 78.75d)');
select healpix_nest(15, '(45d, 84.375d)');
select healpix_nest(15, '(45d, 90d)');
select healpix_nest(15, '(56.25d, -90d)');
select healpix_ring(15, '(56.25d, -84.375d)');
select healpix_nest(15, '(56.25d, -78.75d)');
select healpix_ring(15, '(56.25d, -73.125d)');
select healpix_nest(15, '(56.25d, -67.5d)');
select healpix_nest(15, '(56.25d, -61.875d)');
select healpix_nest(15, '(56.25d, -56.25d)');
select healpix_ring(15, '(56.25d, -50.625d)');
select healpix_ring(15, '(56.25d, -45d)');
select healpix_ring(15, '(56.25d, -39.375d)');
select healpix_nest(15, '(56.25d, -33.75d)');
select healpix_ring(15, '(56.25d, -28.125d)');
select healpix_nest(15, '(56.25d, -22.5d)');
select healpix_nest(15, '(56.25d, -16.875d)');
select healpix_nest(15, '(56.25d, -11.25d)');
select healpix_ring(15, '(56.25d, -5.625d)');
select healpix_nest(15, '(56.25d, 0.0001)');
select healpix_ring(15, '(56.25d, 5.625d)');
select healpix_ring(15, '(56.25d, 11.25d)');
select healpix_ring(15, '(56.25d, 16.875d)');
select healpix_nest(15, '(56.25d, 22.5d)');
select healpix_ring(15, '(56.25d, 28.125d)');
select healpix_nest(15, '(56.25d, 33.75d)');
select healpix_nest(15, '(56.25d, 39.375d)');
select healpix_nest(15, '(56.25d, 45d)');
select healpix_nest(15, '(56.25d, 50.625d)');
select healpix_nest(15, '(56.25d, 56.25d)');
select healpix_nest(15, '(56.25d, 61.875d)');
select healpix_ring(15, '(56.25d, 67.5d)');
select healpix_nest(15, '(56.25d, 73.125d)');
select healpix_ring(15, '(56.25d, 78.75d)');
select healpix_nest(15, '(56.25d, 84.375d)');
select healpix_nest(15, '(56.25d, 90d)');
select healpix_ring(15, '(67.5d, -90d)');
select healpix_ring(15, '(67.5d, -84.375d)');
select healpix_ring(15, '(67.5d, -78.75d)');
select healpix_ring(15, '(67.5d, -73.125d)');
select healpix_ring(15, '(67.5d, -67.5d)');
select healpix_ring(15, '(67.5d, -61.875d)');
select healpix_ring(15, '(67.5d, -56.25d)');
select healpix_nest(15, '(67.5d, -50.625d)');
select healpix_ring(15, '(67.5d, -45d)');
select healpix_nest(15, '(67.5d, -39.375d)');
select healpix_ring(15, '(67.5d, -33.75d)');
select healpix_nest(15, '(67.5d, -28.125d)');
select healpix_ring(15, '(67.5d, -22.5d)');
select healpix_ring(15, '(67.5d, -16.875d)');
select healpix_ring(15, '(67.5d, -11.25d)');
select healpix_ring(15, '(67.5d, -5.625d)');
select healpix_ring(15, '(67.5d, 0.0001)');
select healpix_nest(15, '(67.5d, 5.625d)');
select healpix_nest(15, '(67.5d, 11.25d)');
select healpix_nest(15, '(67.5d, 16.875d)');
select healpix_nest(15, '(67.5d, 22.5d)');
select healpix_ring(15, '(67.5d, 28.125d)');
select healpix_ring(15, '(67.5d, 33.75d)');
select healpix_nest(15, '(67.5d, 39.375d)');
select healpix_ring(15, '(67.5d, 45d)');
select healpix_nest(15, '(67.5d, 50.625d)');
select healpix_nest(15, '(67.5d, 56.25d)');
select healpix_nest(15, '(67.5d, 61.875d)');
select healpix_nest(15, '(67.5d, 67.5d)');
select healpix_nest(15, '(67.5d, 73.125d)');
select healpix_nest(15, '(67.5d, 78.75d)');
select healpix_ring(15, '(67.5d, 84.375d)');
select healpix_nest(15, '(67.5d, 90d)');
select healpix_nest(15, '(78.75d, -90d)');
select healpix_nest(15, '(78.75d, -84.375d)');
select healpix_nest(15, '(78.75d, -78.75d)');
select healpix_ring(15, '(78.75d, -73.125d)');
select healpix_ring(15, '(78.75d, -67.5d)');
select healpix_ring(15, '(78.75d, -61.875d)');
select healpix_ring(15, '(78.75d, -56.25d)');
select healpix_ring(15, '(78.75d, -50.625d)');
select healpix_ring(15, '(78.75d, -45d)');
select healpix_nest(15, '(78.75d, -39.375d)');
select healpix_nest(15, '(78.75d, -33.75d)');
select healpix_ring(15, '(78.75d, -28.125d)');
select healpix_nest(15, '(78.75d, -22.5d)');
select healpix_nest(15, '(78.75d, -16.875d)');
select healpix_ring(15, '(78.75d, -11.25d)');
select healpix_ring(15, '(78.75d, -5.625d)');
select healpix_nest(15, '(78.75d, 0.0001)');
select healpix_nest(15, '(78.75d, 5.625d)');
select healpix_nest(15, '(78.75d, 11.25d)');
select healpix_nest(15, '(78.75d, 16.875d)');
select healpix_ring(15, '(78.75d, 22.5d)');
select healpix_ring(15, '(78.75d, 28.125d)');
select healpix_ring(15, '(78.75d, 33.75d)');
select healpix_ring(15, '(78.75d, 39.375d)');
select healpix_nest(15, '(78.75d, 45d)');
select healpix_nest(15, '(78.75d, 50.625d)');
select healpix_ring(15, '(78.75d, 56.25d)');
select healpix_nest(15, '(78.75d, 61.875d)');
select healpix_ring(15, '(78.75d, 67.5d)');
select healpix_ring(15, '(78.75d, 73.125d)');
select healpix_ring(15, '(78.75d, 78.75d)');
select healpix_ring(15, '(78.75d, 84.375d)');
select healpix_ring(15, '(78.75d, 90d)');
select healpix_ring(15, '(90d, -90d)');
select healpix_ring(15, '(90d, -84.375d)');
select healpix_nest(15, '(90d, -78.75d)');
select healpix_nest(15, '(90d, -73.125d)');
select healpix_ring(15, '(90d, -67.5d)');
select healpix_nest(15, '(90d, -61.875d)');
select healpix_nest(15, '(90d, -56.25d)');
select healpix_ring(15, '(90d, -50.625d)');
select healpix_nest(15, '(90d, -45d)');
select healpix_nest(15, '(90d, -39.375d)');
select healpix_ring(15, '(90d, -33.75d)');
select healpix_nest(15, '(90d, -28.125d)');
select healpix_ring(15, '(90d, -22.5d)');
select healpix_nest(15, '(90d, -16.875d)');
select healpix_ring(15, '(90d, -11.25d)');
select healpix_ring(15, '(90d, -5.625d)');
select healpix_nest(15, '(90d, 0.0001)');
select healpix_ring(15, '(90d, 5.625d)');
select healpix_nest(15, '(90d, 11.25d)');
select healpix_nest(15, '(90d, 16.875d)');
select healpix_nest(15, '(90d, 22.5d)');
select healpix_nest(15, '(90d, 28.125d)');
select healpix_nest(15, '(90d, 33.75d)');
select healpix_nest(15, '(90d, 39.375d)');
select healpix_nest(15, '(90d, 45d)');
select healpix_nest(15, '(90d, 50.625d)');
select healpix_nest(15, '(90d, 56.25d)');
select healpix_ring(15, '(90d, 61.875d)');
select healpix_ring(15, '(90d, 67.5d)');
select healpix_nest(15, '(90d, 73.125d)');
select healpix_nest(15, '(90d, 78.75d)');
select healpix_ring(15, '(90d, 84.375d)');
select healpix_nest(15, '(90d, 90d)');
select healpix_ring(15, '(101.25d, -90d)');
select healpix_nest(15, '(101.25d, -84.375d)');
select healpix_ring(15, '(101.25d, -78.75d)');
select healpix_nest(15, '(101.25d, -73.125d)');
select healpix_ring(15, '(101.25d, -67.5d)');
select healpix_nest(15, '(101.25d, -61.875d)');
select healpix_ring(15, '(101.25d, -56.25d)');
select healpix_nest(15, '(101.25d, -50.625d)');
select healpix_nest(15, '(101.25d, -45d)');
select healpix_ring(15, '(101.25d, -39.375d)');
select healpix_ring(15, '(101.25d, -33.75d)');
select healpix_ring(15, '(101.25d, -28.125d)');
select healpix_ring(15, '(101.25d, -22.5d)');
select healpix_nest(15, '(101.25d, -16.875d)');
select healpix_nest(15, '(101.25d, -11.25d)');
select healpix_nest(15, '(101.25d, -5.625d)');
select healpix_nest(15, '(101.25d, 0.0001)');
select healpix_nest(15, '(101.25d, 5.625d)');
select healpix_ring(15, '(101.25d, 11.25d)');
select healpix_nest(15, '(101.25d, 16.875d)');
select healpix_ring(15, '(101.25d, 22.5d)');
select healpix_ring(15, '(101.25d, 28.125d)');
select healpix_nest(15, '(101.25d, 33.75d)');
select healpix_ring(15, '(101.25d, 39.375d)');
select healpix_nest(15, '(101.25d, 45d)');
select healpix_ring(15, '(101.25d, 50.625d)');
select healpix_ring(15, '(101.25d, 56.25d)');
select healpix_nest(15, '(101.25d, 61.875d)');
select healpix_ring(15, '(101.25d, 67.5d)');
select healpix_nest(15, '(101.25d, 73.125d)');
select healpix_nest(15, '(101.25d, 78.75d)');
select healpix_ring(15, '(101.25d, 84.375d)');
select healpix_nest(15, '(101.25d, 90d)');
select healpix_ring(15, '(112.5d, -90d)');
select healpix_ring(15, '(112.5d, -84.375d)');
select healpix_ring(15, '(112.5d, -78.75d)');
select healpix_ring(15, '(112.5d, -73.125d)');
select healpix_ring(15, '(112.5d, -67.5d)');
select healpix_nest(15, '(112.5d, -61.875d)');
select healpix_nest(15, '(112.5d, -56.25d)');
select healpix_nest(15, '(112.5d, -50.625d)');
select healpix_nest(15, '(112.5d, -45d)');
select healpix_ring(15, '(112.5d, -39.375d)');
select healpix_ring(15, '(112.5d, -33.75d)');
select healpix_ring(15, '(112.5d, -28.125d)');
select healpix_nest(15, '(112.5d, -22.5d)');
select healpix_nest(15, '(112.5d, -16.875d)');
select healpix_nest(15, '(112.5d, -11.25d)');
select healpix_nest(15, '(112.5d, -5.625d)');
select healpix_ring(15, '(112.5d, 0.0001)');
select healpix_nest(15, '(112.5d, 5.625d)');
select healpix_nest(15, '(112.5d, 11.25d)');
select healpix_ring(15, '(112.5d, 16.875d)');
select healpix_ring(15, '(112.5d, 22.5d)');
select healpix_nest(15, '(112.5d, 28.125d)');
select healpix_ring(15, '(112.5d, 33.75d)');
select healpix_nest(15, '(112.5d, 39.375d)');
select healpix_ring(15, '(112.5d, 45d)');
select healpix_nest(15, '(112.5d, 50.625d)');
select healpix_ring(15, '(112.5d, 56.25d)');
select healpix_nest(15, '(112.5d, 61.875d)');
select healpix_nest(15, '(112.5d, 67.5d)');
select healpix_nest(15, '(112.5d, 73.125d)');
select healpix_ring(15, '(112.5d, 78.75d)');
select healpix_ring(15, '(112.5d, 84.375d)');
select healpix_ring(15, '(112.5d, 90d)');
select healpix_ring(15, '(123.75d, -90d)');
select healpix_nest(15, '(123.75d, -84.375d)');
select healpix_nest(15, '(123.75d, -78.75d)');
select healpix_nest(15, '(123.75d, -73.125d)');
select healpix_ring(15, '(123.75d, -67.5d)');
select healpix_nest(15, '(123.75d, -61.875d)');
select healpix_ring(15, '(123.75d, -56.25d)');
select healpix_nest(15, '(123.75d, -50.625d)');
select healpix_nest(15, '(123.75d, -45d)');
select healpix_ring(15, '(123.75d, -39.375d)');
select healpix_nest(15, '(123.75d, -33.75d)');
select healpix_nest(15, '(123.75d, -28.125d)');
select healpix_nest(15, '(123.75d, -22.5d)');
select healpix_nest(15, '(123.75d, -16.875d)');
select healpix_ring(15, '(123.75d, -11.25d)');
select healpix_ring(15, '(123.75d, -5.625d)');
select healpix_ring(15, '(123.75d, 0.0001)');
select healpix_nest(15, '(123.75d, 5.625d)');
select healpix_ring(15, '(123.75d, 11.25d)');
select healpix_nest(15, '(123.75d, 16.875d)');
select healpix_ring(15, '(123.75d, 22.5d)');
select healpix_ring(15, '(123.75d, 28.125d)');
select healpix_nest(15, '(123.75d, 33.75d)');
select healpix_ring(15, '(123.75d, 39.375d)');
select healpix_nest(15, '(123.75d, 45d)');
select healpix_nest(15, '(123.75d, 50.625d)');
select healpix_nest(15, '(123.75d, 56.25d)');
select healpix_ring(15, '(123.75d, 61.875d)');
select healpix_ring(15, '(123.75d, 67.5d)');
select healpix_ring(15, '(123.75d, 73.125d)');
select healpix_nest(15, '(123.75d, 78.75d)');
select healpix_nest(15, '(123.75d, 84.375d)');
select healpix_nest(15, '(123.75d, 90d)');
select healpix_ring(15, '(135d, -90d)');
select healpix_nest(15, '(135d, -84.375d)');
select healpix_nest(15, '(135d, -78.75d)');
select healpix_nest(15, '(135d, -73.125d)');
select healpix_nest(15, '(135d, -67.5d)');
select healpix_ring(15, '(135d, -61.875d)');
select healpix_nest(15, '(135d, -56.25d)');
select healpix_ring(15, '(135d, -50.625d)');
select healpix_nest(15, '(135d, -45d)');
select healpix_ring(15, '(135d, -39.375d)');
select healpix_nest(15, '(135d, -33.75d)');
select healpix_ring(15, '(135d, -28.125d)');
select healpix_ring(15, '(135d, -22.5d)');
select healpix_ring(15, '(135d, -16.875d)');
select healpix_nest(15, '(135d, -11.25d)');
select healpix_ring(15, '(135d, -5.625d)');
select healpix_ring(15, '(135d, 0.0001)');
select healpix_ring(15, '(135d, 5.625d)');
select healpix_ring(15, '(135d, 11.25d)');
select healpix_nest(15, '(135d, 16.875d)');
select healpix_nest(15, '(135d, 22.5d)');
select healpix_nest(15, '(135d, 28.125d)');
select healpix_ring(15, '(135d, 33.75d)');
select healpix_nest(15, '(135d, 39.375d)');
select healpix_nest(15, '(135d, 45d)');
select healpix_ring(15, '(135d, 50.625d)');
select healpix_nest(15, '(135d, 56.25d)');
select healpix_ring(15, '(135d, 61.875d)');
select healpix_ring(15, '(135d, 67.5d)');
select healpix_nest(15, '(135d, 73.125d)');
select healpix_ring(15, '(135d, 78.75d)');
select healpix_nest(15, '(135d, 84.375d)');
select healpix_nest(15, '(135d, 90d)');
select healpix_ring(15, '(146.25d, -90d)');
select healpix_ring(15, '(146.25d, -84.375d)');
select healpix_nest(15, '(146.25d, -78.75d)');
select healpix_ring(15, '(146.25d, -73.125d)');
select healpix_nest(15, '(146.25d, -67.5d)');
select healpix_ring(15, '(146.25d, -61.875d)');
select healpix_ring(15, '(146.25d, -56.25d)');
select healpix_ring(15, '(146.25d, -50.625d)');
select healpix_ring(15, '(146.25d, -45d)');
select healpix_ring(15, '(146.25d, -39.375d)');
select healpix_nest(15, '(146.25d, -33.75d)');
select healpix_nest(15, '(146.25d, -28.125d)');
select healpix_ring(15, '(146.25d, -22.5d)');
select healpix_ring(15, '(146.25d, -16.875d)');
select healpix_nest(15, '(146.25d, -11.25d)');
select healpix_ring(15, '(146.25d, -5.625d)');
select healpix_ring(15, '(146.25d, 0.0001)');
select healpix_ring(15, '(146.25d, 5.625d)');
select healpix_ring(15, '(146.25d, 11.25d)');
select healpix_nest(15, '(146.25d, 16.875d)');
select healpix_ring(15, '(146.25d, 22.5d)');
select healpix_ring(15, '(146.25d, 28.125d)');
select healpix_ring(15, '(146.25d, 33.75d)');
select healpix_ring(15, '(146.25d, 39.375d)');
select healpix_ring(15, '(146.25d, 45d)');
select healpix_nest(15, '(146.25d, 50.625d)');
select healpix_nest(15, '(146.25d, 56.25d)');
select healpix_nest(15, '(146.25d, 61.875d)');
select healpix_nest(15, '(146.25d, 67.5d)');
select healpix_ring(15, '(146.25d, 73.125d)');
select healpix_nest(15, '(146.25d, 78.75d)');
select healpix_ring(15, '(146.25d, 84.375d)');
select healpix_nest(15, '(146.25d, 90d)');
select healpix_ring(15, '(157.5d, -90d)');
select healpix_nest(15, '(157.5d, -84.375d)');
select healpix_nest(15, '(157.5d, -78.75d)');
select healpix_ring(15, '(157.5d, -73.125d)');
select healpix_ring(15, '(157.5d, -67.5d)');
select healpix_nest(15, '(157.5d, -61.875d)');
select healpix_nest(15, '(157.5d, -56.25d)');
select healpix_ring(15, '(157.5d, -50.625d)');
select healpix_ring(15, '(157.5d, -45d)');
select healpix_nest(15, '(157.5d, -39.375d)');
select healpix_nest(15, '(157.5d, -33.75d)');
select healpix_nest(15, '(157.5d, -28.125d)');
select healpix_ring(15, '(157.5d, -22.5d)');
select healpix_nest(15, '(157.5d, -16.875d)');
select healpix_nest(15, '(157.5d, -11.25d)');
select healpix_nest(15, '(157.5d, -5.625d)');
select healpix_ring(15, '(157.5d, 0.0001)');
select healpix_nest(15, '(157.5d, 5.625d)');
select healpix_nest(15, '(157.5d, 11.25d)');
select healpix_ring(15, '(157.5d, 16.875d)');
select healpix_nest(15, '(157.5d, 22.5d)');
select healpix_ring(15, '(157.5d, 28.125d)');
select healpix_nest(15, '(157.5d, 33.75d)');
select healpix_ring(15, '(157.5d, 39.375d)');
select healpix_nest(15, '(157.5d, 45d)');
select healpix_nest(15, '(157.5d, 50.625d)');
select healpix_ring(15, '(157.5d, 56.25d)');
select healpix_ring(15, '(157.5d, 61.875d)');
select healpix_ring(15, '(157.5d, 67.5d)');
select healpix_nest(15, '(157.5d, 73.125d)');
select healpix_ring(15, '(157.5d, 78.75d)');
select healpix_nest(15, '(157.5d, 84.375d)');
select healpix_nest(15, '(157.5d, 90d)');
select healpix_nest(15, '(168.75d, -90d)');
select healpix_ring(15, '(168.75d, -84.375d)');
select healpix_nest(15, '(168.75d, -78.75d)');
select healpix_ring(15, '(168.75d, -73.125d)');
select healpix_nest(15, '(168.75d, -67.5d)');
select healpix_ring(15, '(168.75d, -61.875d)');
select healpix_nest(15, '(168.75d, -56.25d)');
select healpix_nest(15, '(168.75d, -50.625d)');
select healpix_nest(15, '(168.75d, -45d)');
select healpix_nest(15, '(168.75d, -39.375d)');
select healpix_ring(15, '(168.75d, -33.75d)');
select healpix_ring(15, '(168.75d, -28.125d)');
select healpix_ring(15, '(168.75d, -22.5d)');
select healpix_ring(15, '(168.75d, -16.875d)');
select healpix_ring(15, '(168.75d, -11.25d)');
select healpix_nest(15, '(168.75d, -5.625d)');
select healpix_nest(15, '(168.75d, 0.0001)');
select healpix_ring(15, '(168.75d, 5.625d)');
select healpix_ring(15, '(168.75d, 11.25d)');
select healpix_ring(15, '(168.75d, 16.875d)');
select healpix_ring(15, '(168.75d, 22.5d)');
select healpix_nest(15, '(168.75d, 28.125d)');
select healpix_ring(15, '(168.75d, 33.75d)');
select healpix_ring(15, '(168.75d, 39.375d)');
select healpix_nest(15, '(168.75d, 45d)');
select healpix_ring(15, '(168.75d, 50.625d)');
select healpix_ring(15, '(168.75d, 56.25d)');
select healpix_ring(15, '(168.75d, 61.875d)');
select healpix_nest(15, '(168.75d, 67.5d)');
select healpix_ring(15, '(168.75d, 73.125d)');
select healpix_nest(15, '(168.75d, 78.75d)');
select healpix_ring(15, '(168.75d, 84.375d)');
select healpix_nest(15, '(168.75d, 90d)');
select healpix_nest(15, '(180d, -90d)');
select healpix_ring(15, '(180d, -84.375d)');
select healpix_nest(15, '(180d, -78.75d)');
select healpix_ring(15, '(180d, -73.125d)');
select healpix_nest(15, '(180d, -67.5d)');
select healpix_ring(15, '(180d, -61.875d)');
select healpix_ring(15, '(180d, -56.25d)');
select healpix_ring(15, '(180d, -50.625d)');
select healpix_ring(15, '(180d, -45d)');
select healpix_nest(15, '(180d, -39.375d)');
select healpix_nest(15, '(180d, -33.75d)');
select healpix_ring(15, '(180d, -28.125d)');
select healpix_nest(15, '(180d, -22.5d)');
select healpix_nest(15, '(180d, -16.875d)');
select healpix_nest(15, '(180d, -11.25d)');
select healpix_nest(15, '(180d, -5.625d)');
select healpix_nest(15, '(180d, 0.0001)');
select healpix_ring(15, '(180d, 5.625d)');
select healpix_ring(15, '(180d, 11.25d)');
select healpix_nest(15, '(180d, 16.875d)');
select healpix_nest(15, '(180d, 22.5d)');
select healpix_ring(15, '(180d, 28.125d)');
select healpix_ring(15, '(180d, 33.75d)');
select healpix_nest(15, '(180d, 39.375d)');
select healpix_ring(15, '(180d, 45d)');
select healpix_ring(15, '(180d, 50.625d)');
select healpix_ring(15, '(180d, 56.25d)');
select healpix_nest(15, '(180d, 61.875d)');
select healpix_nest(15, '(180d, 67.5d)');
select healpix_nest(15, '(180d, 73.125d)');
select healpix_ring(15, '(180d, 78.75d)');
select healpix_nest(15, '(180d, 84.375d)');
select healpix_nest(15, '(180d, 90d)');
select healpix_nest(15, '(191.25d, -90d)');
select healpix_ring(15, '(191.25d, -84.375d)');
select healpix_ring(15, '(191.25d, -78.75d)');
select healpix_ring(15, '(191.25d, -73.125d)');
select healpix_ring(15, '(191.25d, -67.5d)');
select healpix_nest(15, '(191.25d, -61.875d)');
select healpix_nest(15, '(191.25d, -56.25d)');
select healpix_nest(15, '(191.25d, -50.625d)');
select healpix_ring(15, '(191.25d, -45d)');
select healpix_ring(15, '(191.25d, -39.375d)');
select healpix_ring(15, '(191.25d, -33.75d)');
select healpix_nest(15, '(191.25d, -28.125d)');
select healpix_ring(15, '(191.25d, -22.5d)');
select healpix_nest(15, '(191.25d, -16.875d)');
select healpix_nest(15, '(191.25d, -11.25d)');
select healpix_ring(15, '(191.25d, -5.625d)');
select healpix_ring(15, '(191.25d, 0.0001)');
select healpix_nest(15, '(191.25d, 5.625d)');
select healpix_ring(15, '(191.25d, 11.25d)');
select healpix_ring(15, '(191.25d, 16.875d)');
select healpix_nest(15, '(191.25d, 22.5d)');
select healpix_nest(15, '(191.25d, 28.125d)');
select healpix_ring(15, '(191.25d, 33.75d)');
select healpix_nest(15, '(191.25d, 39.375d)');
select healpix_nest(15, '(191.25d, 45d)');
select healpix_nest(15, '(191.25d, 50.625d)');
select healpix_ring(15, '(191.25d, 56.25d)');
select healpix_ring(15, '(191.25d, 61.875d)');
select healpix_ring(15, '(191.25d, 67.5d)');
select healpix_nest(15, '(191.25d, 73.125d)');
select healpix_ring(15, '(191.25d, 78.75d)');
select healpix_nest(15, '(191.25d, 84.375d)');
select healpix_ring(15, '(191.25d, 90d)');
select healpix_ring(15, '(202.5d, -90d)');
select healpix_nest(15, '(202.5d, -84.375d)');
select healpix_ring(15, '(202.5d, -78.75d)');
select healpix_nest(15, '(202.5d, -73.125d)');
select healpix_ring(15, '(202.5d, -67.5d)');
select healpix_nest(15, '(202.5d, -61.875d)');
select healpix_nest(15, '(202.5d, -56.25d)');
select healpix_ring(15, '(202.5d, -50.625d)');
select healpix_ring(15, '(202.5d, -45d)');
select healpix_ring(15, '(202.5d, -39.375d)');
select healpix_nest(15, '(202.5d, -33.75d)');
select healpix_ring(15, '(202.5d, -28.125d)');
select healpix_nest(15, '(202.5d, -22.5d)');
select healpix_nest(15, '(202.5d, -16.875d)');
select healpix_nest(15, '(202.5d, -11.25d)');
select healpix_nest(15, '(202.5d, -5.625d)');
select healpix_ring(15, '(202.5d, 0.0001)');
select healpix_ring(15, '(202.5d, 5.625d)');
select healpix_ring(15, '(202.5d, 11.25d)');
select healpix_ring(15, '(202.5d, 16.875d)');
select healpix_nest(15, '(202.5d, 22.5d)');
select healpix_nest(15, '(202.5d, 28.125d)');
select healpix_nest(15, '(202.5d, 33.75d)');
select healpix_ring(15, '(202.5d, 39.375d)');
select healpix_nest(15, '(202.5d, 45d)');
select healpix_ring(15, '(202.5d, 50.625d)');
select healpix_nest(15, '(202.5d, 56.25d)');
select healpix_nest(15, '(202.5d, 61.875d)');
select healpix_nest(15, '(202.5d, 67.5d)');
select healpix_nest(15, '(202.5d, 73.125d)');
select healpix_ring(15, '(202.5d, 78.75d)');
select healpix_ring(15, '(202.5d, 84.375d)');
select healpix_ring(15, '(202.5d, 90d)');
select healpix_nest(15, '(213.75d, -90d)');
select healpix_ring(15, '(213.75d, -84.375d)');
select healpix_ring(15, '(213.75d, -78.75d)');
select healpix_nest(15, '(213.75d, -73.125d)');
select healpix_nest(15, '(213.75d, -67.5d)');
select healpix_nest(15, '(213.75d, -61.875d)');
select healpix_ring(15, '(213.75d, -56.25d)');
select healpix_ring(15, '(213.75d, -50.625d)');
select healpix_nest(15, '(213.75d, -45d)');
select healpix_nest(15, '(213.75d, -39.375d)');
select healpix_ring(15, '(213.75d, -33.75d)');
select healpix_ring(15, '(213.75d, -28.125d)');
select healpix_ring(15, '(213.75d, -22.5d)');
select healpix_ring(15, '(213.75d, -16.875d)');
select healpix_nest(15, '(213.75d, -11.25d)');
select healpix_ring(15, '(213.75d, -5.625d)');
select healpix_nest(15, '(213.75d, 0.0001)');
select healpix_nest(15, '(213.75d, 5.625d)');
select healpix_nest(15, '(213.75d, 11.25d)');
select healpix_nest(15, '(213.75d, 16.875d)');
select healpix_ring(15, '(213.75d, 22.5d)');
select healpix_nest(15, '(213.75d, 28.125d)');
select healpix_ring(15, '(213.75d, 33.75d)');
select healpix_ring(15, '(213.75d, 39.375d)');
select healpix_ring(15, '(213.75d, 45d)');
select healpix_ring(15, '(213.75d, 50.625d)');
select healpix_nest(15, '(213.75d, 56.25d)');
select healpix_ring(15, '(213.75d, 61.875d)');
select healpix_nest(15, '(213.75d, 67.5d)');
select healpix_nest(15, '(213.75d, 73.125d)');
select healpix_ring(15, '(213.75d, 78.75d)');
select healpix_ring(15, '(213.75d, 84.375d)');
select healpix_nest(15, '(213.75d, 90d)');
select healpix_nest(15, '(225d, -90d)');
select healpix_ring(15, '(225d, -84.375d)');
select healpix_ring(15, '(225d, -78.75d)');
select healpix_ring(15, '(225d, -73.125d)');
select healpix_ring(15, '(225d, -67.5d)');
select healpix_nest(15, '(225d, -61.875d)');
select healpix_nest(15, '(225d, -56.25d)');
select healpix_ring(15, '(225d, -50.625d)');
select healpix_nest(15, '(225d, -45d)');
select healpix_nest(15, '(225d, -39.375d)');
select healpix_ring(15, '(225d, -33.75d)');
select healpix_ring(15, '(225d, -28.125d)');
select healpix_nest(15, '(225d, -22.5d)');
select healpix_ring(15, '(225d, -16.875d)');
select healpix_nest(15, '(225d, -11.25d)');
select healpix_nest(15, '(225d, -5.625d)');
select healpix_ring(15, '(225d, 0.0001)');
select healpix_nest(15, '(225d, 5.625d)');
select healpix_ring(15, '(225d, 11.25d)');
select healpix_nest(15, '(225d, 16.875d)');
select healpix_nest(15, '(225d, 22.5d)');
select healpix_ring(15, '(225d, 28.125d)');
select healpix_ring(15, '(225d, 33.75d)');
select healpix_nest(15, '(225d, 39.375d)');
select healpix_nest(15, '(225d, 45d)');
select healpix_nest(15, '(225d, 50.625d)');
select healpix_ring(15, '(225d, 56.25d)');
select healpix_ring(15, '(225d, 61.875d)');
select healpix_ring(15, '(225d, 67.5d)');
select healpix_ring(15, '(225d, 73.125d)');
select healpix_nest(15, '(225d, 78.75d)');
select healpix_ring(15, '(225d, 84.375d)');
select healpix_nest(15, '(225d, 90d)');
select healpix_nest(15, '(236.25d, -90d)');
select healpix_ring(15, '(236.25d, -84.375d)');
select healpix_nest(15, '(236.25d, -78.75d)');
select healpix_nest(15, '(236.25d, -73.125d)');
select healpix_ring(15, '(236.25d, -67.5d)');
select healpix_nest(15, '(236.25d, -61.875d)');
select healpix_ring(15, '(236.25d, -56.25d)');
select healpix_nest(15, '(236.25d, -50.625d)');
select healpix_nest(15, '(236.25d, -45d)');
select healpix_ring(15, '(236.25d, -39.375d)');
select healpix_ring(15, '(236.25d, -33.75d)');
select healpix_nest(15, '(236.25d, -28.125d)');
select healpix_ring(15, '(236.25d, -22.5d)');
select healpix_ring(15, '(236.25d, -16.875d)');
select healpix_ring(15, '(236.25d, -11.25d)');
select healpix_ring(15, '(236.25d, -5.625d)');
select healpix_nest(15, '(236.25d, 0.0001)');
select healpix_nest(15, '(236.25d, 5.625d)');
select healpix_nest(15, '(236.25d, 11.25d)');
select healpix_nest(15, '(236.25d, 16.875d)');
select healpix_nest(15, '(236.25d, 22.5d)');
select healpix_ring(15, '(236.25d, 28.125d)');
select healpix_ring(15, '(236.25d, 33.75d)');
select healpix_ring(15, '(236.25d, 39.375d)');
select healpix_nest(15, '(236.25d, 45d)');
select healpix_nest(15, '(236.25d, 50.625d)');
select healpix_nest(15, '(236.25d, 56.25d)');
select healpix_nest(15, '(236.25d, 61.875d)');
select healpix_ring(15, '(236.25d, 67.5d)');
select healpix_ring(15, '(236.25d, 73.125d)');
select healpix_nest(15, '(236.25d, 78.75d)');
select healpix_ring(15, '(236.25d, 84.375d)');
select healpix_ring(15, '(236.25d, 90d)');
select healpix_nest(15, '(247.5d, -90d)');
select healpix_nest(15, '(247.5d, -84.375d)');
select healpix_ring(15, '(247.5d, -78.75d)');
select healpix_nest(15, '(247.5d, -73.125d)');
select healpix_ring(15, '(247.5d, -67.5d)');
select healpix_nest(15, '(247.5d, -61.875d)');
select healpix_ring(15, '(247.5d, -56.25d)');
select healpix_ring(15, '(247.5d, -50.625d)');
select healpix_nest(15, '(247.5d, -45d)');
select healpix_ring(15, '(247.5d, -39.375d)');
select healpix_nest(15, '(247.5d, -33.75d)');
select healpix_nest(15, '(247.5d, -28.125d)');
select healpix_ring(15, '(247.5d, -22.5d)');
select healpix_nest(15, '(247.5d, -16.875d)');
select healpix_ring(15, '(247.5d, -11.25d)');
select healpix_nest(15, '(247.5d, -5.625d)');
select healpix_nest(15, '(247.5d, 0.0001)');
select healpix_ring(15, '(247.5d, 5.625d)');
select healpix_ring(15, '(247.5d, 11.25d)');
select healpix_ring(15, '(247.5d, 16.875d)');
select healpix_ring(15, '(247.5d, 22.5d)');
select healpix_ring(15, '(247.5d, 28.125d)');
select healpix_ring(15, '(247.5d, 33.75d)');
select healpix_ring(15, '(247.5d, 39.375d)');
select healpix_ring(15, '(247.5d, 45d)');
select healpix_nest(15, '(247.5d, 50.625d)');
select healpix_nest(15, '(247.5d, 56.25d)');
select healpix_nest(15, '(247.5d, 61.875d)');
select healpix_nest(15, '(247.5d, 67.5d)');
select healpix_nest(15, '(247.5d, 73.125d)');
select healpix_ring(15, '(247.5d, 78.75d)');
select healpix_nest(15, '(247.5d, 84.375d)');
select healpix_nest(15, '(247.5d, 90d)');
select healpix_nest(15, '(258.75d, -90d)');
select healpix_nest(15, '(258.75d, -84.375d)');
select healpix_nest(15, '(258.75d, -78.75d)');
select healpix_nest(15, '(258.75d, -73.125d)');
select healpix_nest(15, '(258.75d, -67.5d)');
select healpix_ring(15, '(258.75d, -61.875d)');
select healpix_ring(15, '(258.75d, -56.25d)');
select healpix_ring(15, '(258.75d, -50.625d)');
select healpix_nest(15, '(258.75d, -45d)');
select healpix_nest(15, '(258.75d, -39.375d)');
select healpix_ring(15, '(258.75d, -33.75d)');
select healpix_nest(15, '(258.75d, -28.125d)');
select healpix_ring(15, '(258.75d, -22.5d)');
select healpix_ring(15, '(258.75d, -16.875d)');
select healpix_nest(15, '(258.75d, -11.25d)');
select healpix_nest(15, '(258.75d, -5.625d)');
select healpix_ring(15, '(258.75d, 0.0001)');
select healpix_ring(15, '(258.75d, 5.625d)');
select healpix_nest(15, '(258.75d, 11.25d)');
select healpix_nest(15, '(258.75d, 16.875d)');
select healpix_nest(15, '(258.75d, 22.5d)');
select healpix_nest(15, '(258.75d, 28.125d)');
select healpix_ring(15, '(258.75d, 33.75d)');
select healpix_nest(15, '(258.75d, 39.375d)');
select healpix_nest(15, '(258.75d, 45d)');
select healpix_nest(15, '(258.75d, 50.625d)');
select healpix_ring(15, '(258.75d, 56.25d)');
select healpix_ring(15, '(258.75d, 61.875d)');
select healpix_ring(15, '(258.75d, 67.5d)');
select healpix_nest(15, '(258.75d, 73.125d)');
select healpix_ring(15, '(258.75d, 78.75d)');
select healpix_nest(15, '(258.75d, 84.375d)');
select healpix_ring(15, '(258.75d, 90d)');
select healpix_ring(15, '(270d, -90d)');
select healpix_nest(15, '(270d, -84.375d)');
select healpix_ring(15, '(270d, -78.75d)');
select healpix_nest(15, '(270d, -73.125d)');
select healpix_ring(15, '(270d, -67.5d)');
select healpix_ring(15, '(270d, -61.875d)');
select healpix_nest(15, '(270d, -56.25d)');
select healpix_nest(15, '(270d, -50.625d)');
select healpix_nest(15, '(270d, -45d)');
select healpix_nest(15, '(270d, -39.375d)');
select healpix_ring(15, '(270d, -33.75d)');
select healpix_nest(15, '(270d, -28.125d)');
select healpix_ring(15, '(270d, -22.5d)');
select healpix_nest(15, '(270d, -16.875d)');
select healpix_ring(15, '(270d, -11.25d)');
select healpix_nest(15, '(270d, -5.625d)');
select healpix_ring(15, '(270d, 0.0001)');
select healpix_nest(15, '(270d, 5.625d)');
select healpix_ring(15, '(270d, 11.25d)');
select healpix_ring(15, '(270d, 16.875d)');
select healpix_nest(15, '(270d, 22.5d)');
select healpix_nest(15, '(270d, 28.125d)');
select healpix_ring(15, '(270d, 33.75d)');
select healpix_nest(15, '(270d, 39.375d)');
select healpix_nest(15, '(270d, 45d)');
select healpix_ring(15, '(270d, 50.625d)');
select healpix_ring(15, '(270d, 56.25d)');
select healpix_nest(15, '(270d, 61.875d)');
select healpix_ring(15, '(270d, 67.5d)');
select healpix_nest(15, '(270d, 73.125d)');
select healpix_nest(15, '(270d, 78.75d)');
select healpix_nest(15, '(270d, 84.375d)');
select healpix_nest(15, '(270d, 90d)');
select healpix_ring(15, '(281.25d, -90d)');
select healpix_nest(15, '(281.25d, -84.375d)');
select healpix_nest(15, '(281.25d, -78.75d)');
select healpix_ring(15, '(281.25d, -73.125d)');
select healpix_ring(15, '(281.25d, -67.5d)');
select healpix_nest(15, '(281.25d, -61.875d)');
select healpix_ring(15, '(281.25d, -56.25d)');
select healpix_ring(15, '(281.25d, -50.625d)');
select healpix_ring(15, '(281.25d, -45d)');
select healpix_ring(15, '(281.25d, -39.375d)');
select healpix_ring(15, '(281.25d, -33.75d)');
select healpix_nest(15, '(281.25d, -28.125d)');
select healpix_nest(15, '(281.25d, -22.5d)');
select healpix_ring(15, '(281.25d, -16.875d)');
select healpix_nest(15, '(281.25d, -11.25d)');
select healpix_ring(15, '(281.25d, -5.625d)');
select healpix_nest(15, '(281.25d, 0.0001)');
select healpix_ring(15, '(281.25d, 5.625d)');
select healpix_ring(15, '(281.25d, 11.25d)');
select healpix_nest(15, '(281.25d, 16.875d)');
select healpix_nest(15, '(281.25d, 22.5d)');
select healpix_ring(15, '(281.25d, 28.125d)');
select healpix_nest(15, '(281.25d, 33.75d)');
select healpix_ring(15, '(281.25d, 39.375d)');
select healpix_ring(15, '(281.25d, 45d)');
select healpix_nest(15, '(281.25d, 50.625d)');
select healpix_ring(15, '(281.25d, 56.25d)');
select healpix_nest(15, '(281.25d, 61.875d)');
select healpix_ring(15, '(281.25d, 67.5d)');
select healpix_nest(15, '(281.25d, 73.125d)');
select healpix_nest(15, '(281.25d, 78.75d)');
select healpix_nest(15, '(281.25d, 84.375d)');
select healpix_ring(15, '(281.25d, 90d)');
select healpix_nest(15, '(292.5d, -90d)');
select healpix_ring(15, '(292.5d, -84.375d)');
select healpix_nest(15, '(292.5d, -78.75d)');
select healpix_nest(15, '(292.5d, -73.125d)');
select healpix_ring(15, '(292.5d, -67.5d)');
select healpix_nest(15, '(292.5d, -61.875d)');
select healpix_nest(15, '(292.5d, -56.25d)');
select healpix_ring(15, '(292.5d, -50.625d)');
select healpix_nest(15, '(292.5d, -45d)');
select healpix_ring(15, '(292.5d, -39.375d)');
select healpix_nest(15, '(292.5d, -33.75d)');
select healpix_ring(15, '(292.5d, -28.125d)');
select healpix_nest(15, '(292.5d, -22.5d)');
select healpix_nest(15, '(292.5d, -16.875d)');
select healpix_nest(15, '(292.5d, -11.25d)');
select healpix_ring(15, '(292.5d, -5.625d)');
select healpix_nest(15, '(292.5d, 0.0001)');
select healpix_ring(15, '(292.5d, 5.625d)');
select healpix_nest(15, '(292.5d, 11.25d)');
select healpix_ring(15, '(292.5d, 16.875d)');
select healpix_nest(15, '(292.5d, 22.5d)');
select healpix_ring(15, '(292.5d, 28.125d)');
select healpix_ring(15, '(292.5d, 33.75d)');
select healpix_ring(15, '(292.5d, 39.375d)');
select healpix_nest(15, '(292.5d, 45d)');
select healpix_ring(15, '(292.5d, 50.625d)');
select healpix_nest(15, '(292.5d, 56.25d)');
select healpix_ring(15, '(292.5d, 61.875d)');
select healpix_ring(15, '(292.5d, 67.5d)');
select healpix_ring(15, '(292.5d, 73.125d)');
select healpix_nest(15, '(292.5d, 78.75d)');
select healpix_ring(15, '(292.5d, 84.375d)');
select healpix_ring(15, '(292.5d, 90d)');
select healpix_ring(15, '(303.75d, -90d)');
select healpix_nest(15, '(303.75d, -84.375d)');
select healpix_nest(15, '(303.75d, -78.75d)');
select healpix_ring(15, '(303.75d, -73.125d)');
select healpix_nest(15, '(303.75d, -67.5d)');
select healpix_nest(15, '(303.75d, -61.875d)');
select healpix_ring(15, '(303.75d, -56.25d)');
select healpix_ring(15, '(303.75d, -50.625d)');
select healpix_nest(15, '(303.75d, -45d)');
select healpix_nest(15, '(303.75d, -39.375d)');
select healpix_nest(15, '(303.75d, -33.75d)');
select healpix_ring(15, '(303.75d, -28.125d)');
select healpix_ring(15, '(303.75d, -22.5d)');
select healpix_ring(15, '(303.75d, -16.875d)');
select healpix_nest(15, '(303.75d, -11.25d)');
select healpix_nest(15, '(303.75d, -5.625d)');
select healpix_nest(15, '(303.75d, 0.0001)');
select healpix_ring(15, '(303.75d, 5.625d)');
select healpix_nest(15, '(303.75d, 11.25d)');
select healpix_ring(15, '(303.75d, 16.875d)');
select healpix_ring(15, '(303.75d, 22.5d)');
select healpix_ring(15, '(303.75d, 28.125d)');
select healpix_nest(15, '(303.75d, 33.75d)');
select healpix_nest(15, '(303.75d, 39.375d)');
select healpix_nest(15, '(303.75d, 45d)');
select healpix_ring(15, '(303.75d, 50.625d)');
select healpix_nest(15, '(303.75d, 56.25d)');
select healpix_nest(15, '(303.75d, 61.875d)');
select healpix_ring(15, '(303.75d, 67.5d)');
select healpix_ring(15, '(303.75d, 73.125d)');
select healpix_nest(15, '(303.75d, 78.75d)');
select healpix_nest(15, '(303.75d, 84.375d)');
select healpix_nest(15, '(303.75d, 90d)');
select healpix_nest(15, '(315d, -90d)');
select healpix_nest(15, '(315d, -84.375d)');
select healpix_ring(15, '(315d, -78.75d)');
select healpix_ring(15, '(315d, -73.125d)');
select healpix_ring(15, '(315d, -67.5d)');
select healpix_nest(15, '(315d, -61.875d)');
select healpix_ring(15, '(315d, -56.25d)');
select healpix_nest(15, '(315d, -50.625d)');
select healpix_nest(15, '(315d, -45d)');
select healpix_nest(15, '(315d, -39.375d)');
select healpix_nest(15, '(315d, -33.75d)');
select healpix_ring(15, '(315d, -28.125d)');
select healpix_nest(15, '(315d, -22.5d)');
select healpix_ring(15, '(315d, -16.875d)');
select healpix_nest(15, '(315d, -11.25d)');
select healpix_ring(15, '(315d, -5.625d)');
select healpix_ring(15, '(315d, 0.0001)');
select healpix_nest(15, '(315d, 5.625d)');
select healpix_nest(15, '(315d, 11.25d)');
select healpix_nest(15, '(315d, 16.875d)');
select healpix_ring(15, '(315d, 22.5d)');
select healpix_nest(15, '(315d, 28.125d)');
select healpix_nest(15, '(315d, 33.75d)');
select healpix_nest(15, '(315d, 39.375d)');
select healpix_nest(15, '(315d, 45d)');
select healpix_nest(15, '(315d, 50.625d)');
select healpix_ring(15, '(315d, 56.25d)');
select healpix_ring(15, '(315d, 61.875d)');
select healpix_nest(15, '(315d, 67.5d)');
select healpix_nest(15, '(315d, 73.125d)');
select healpix_nest(15, '(315d, 78.75d)');
select healpix_nest(15, '(315d, 84.375d)');
select healpix_ring(15, '(315d, 90d)');
select healpix_ring(15, '(326.25d, -90d)');
select healpix_nest(15, '(326.25d, -84.375d)');
select healpix_ring(15, '(326.25d, -78.75d)');
select healpix_ring(15, '(326.25d, -73.125d)');
select healpix_ring(15, '(326.25d, -67.5d)');
select healpix_ring(15, '(326.25d, -61.875d)');
select healpix_nest(15, '(326.25d, -56.25d)');
select healpix_nest(15, '(326.25d, -50.625d)');
select healpix_nest(15, '(326.25d, -45d)');
select healpix_ring(15, '(326.25d, -39.375d)');
select healpix_nest(15, '(326.25d, -33.75d)');
select healpix_ring(15, '(326.25d, -28.125d)');
select healpix_ring(15, '(326.25d, -22.5d)');
select healpix_ring(15, '(326.25d, -16.875d)');
select healpix_nest(15, '(326.25d, -11.25d)');
select healpix_ring(15, '(326.25d, -5.625d)');
select healpix_ring(15, '(326.25d, 0.0001)');
select healpix_nest(15, '(326.25d, 5.625d)');
select healpix_ring(15, '(326.25d, 11.25d)');
select healpix_ring(15, '(326.25d, 16.875d)');
select healpix_ring(15, '(326.25d, 22.5d)');
select healpix_nest(15, '(326.25d, 28.125d)');
select healpix_ring(15, '(326.25d, 33.75d)');
select healpix_nest(15, '(326.25d, 39.375d)');
select healpix_nest(15, '(326.25d, 45d)');
select healpix_ring(15, '(326.25d, 50.625d)');
select healpix_ring(15, '(326.25d, 56.25d)');
select healpix_ring(15, '(326.25d, 61.875d)');
select healpix_ring(15, '(326.25d, 67.5d)');
select healpix_nest(15, '(326.25d, 73.125d)');
select healpix_ring(15, '(326.25d, 78.75d)');
select healpix_ring(15, '(326.25d, 84.375d)');
select healpix_ring(15, '(326.25d, 90d)');
select healpix_ring(15, '(337.5d, -90d)');
select healpix_nest(15, '(337.5d, -84.375d)');
select healpix_nest(15, '(337.5d, -78.75d)');
select healpix_ring(15, '(337.5d, -73.125d)');
select healpix_ring(15, '(337.5d, -67.5d)');
select healpix_ring(15, '(337.5d, -61.875d)');
select healpix_ring(15, '(337.5d, -56.25d)');
select healpix_ring(15, '(337.5d, -50.625d)');
select healpix_ring(15, '(337.5d, -45d)');
select healpix_ring(15, '(337.5d, -39.375d)');
select healpix_nest(15, '(337.5d, -33.75d)');
select healpix_ring(15, '(337.5d, -28.125d)');
select healpix_ring(15, '(337.5d, -22.5d)');
select healpix_nest(15, '(337.5d, -16.875d)');
select healpix_ring(15, '(337.5d, -11.25d)');
select healpix_ring(15, '(337.5d, -5.625d)');
select healpix_nest(15, '(337.5d, 0.0001)');
select healpix_ring(15, '(337.5d, 5.625d)');
select healpix_nest(15, '(337.5d, 11.25d)');
select healpix_nest(15, '(337.5d, 16.875d)');
select healpix_ring(15, '(337.5d, 22.5d)');
select healpix_nest(15, '(337.5d, 28.125d)');
select healpix_nest(15, '(337.5d, 33.75d)');
select healpix_nest(15, '(337.5d, 39.375d)');
select healpix_ring(15, '(337.5d, 45d)');
select healpix_nest(15, '(337.5d, 50.625d)');
select healpix_ring(15, '(337.5d, 56.25d)');
select healpix_nest(15, '(337.5d, 61.875d)');
select healpix_nest(15, '(337.5d, 67.5d)');
select healpix_ring(15, '(337.5d, 73.125d)');
select healpix_ring(15, '(337.5d, 78.75d)');
select healpix_ring(15, '(337.5d, 84.375d)');
select healpix_nest(15, '(337.5d, 90d)');
select healpix_nest(15, '(348.75d, -90d)');
select healpix_ring(15, '(348.75d, -84.375d)');
select healpix_nest(15, '(348.75d, -78.75d)');
select healpix_nest(15, '(348.75d, -73.125d)');
select healpix_ring(15, '(348.75d, -67.5d)');
select healpix_nest(15, '(348.75d, -61.875d)');
select healpix_nest(15, '(348.75d, -56.25d)');
select healpix_nest(15, '(348.75d, -50.625d)');
select healpix_ring(15, '(348.75d, -45d)');
select healpix_ring(15, '(348.75d, -39.375d)');
select healpix_ring(15, '(348.75d, -33.75d)');
select healpix_ring(15, '(348.75d, -28.125d)');
select healpix_nest(15, '(348.75d, -22.5d)');
select healpix_nest(15, '(348.75d, -16.875d)');
select healpix_ring(15, '(348.75d, -11.25d)');
select healpix_ring(15, '(348.75d, -5.625d)');
select healpix_ring(15, '(348.75d, 0.0001)');
select healpix_ring(15, '(348.75d, 5.625d)');
select healpix_ring(15, '(348.75d, 11.25d)');
select healpix_nest(15, '(348.75d, 16.875d)');
select healpix_nest(15, '(348.75d, 22.5d)');
select healpix_ring(15, '(348.75d, 28.125d)');
select healpix_ring(15, '(348.75d, 33.75d)');
select healpix_ring(15, '(348.75d, 39.375d)');
select healpix_ring(15, '(348.75d, 45d)');
select healpix_ring(15, '(348.75d, 50.625d)');
select healpix_ring(15, '(348.75d, 56.25d)');
select healpix_ring(15, '(348.75d, 61.875d)');
select healpix_ring(15, '(348.75d, 67.5d)');
select healpix_nest(15, '(348.75d, 73.125d)');
select healpix_ring(15, '(348.75d, 78.75d)');
select healpix_ring(15, '(348.75d, 84.375d)');
select healpix_nest(15, '(348.75d, 90d)');
select healpix_nest(15, '(360d, -90d)');
select healpix_ring(15, '(360d, -84.375d)');
select healpix_ring(15, '(360d, -78.75d)');
select healpix_ring(15, '(360d, -73.125d)');
select healpix_ring(15, '(360d, -67.5d)');
select healpix_nest(15, '(360d, -61.875d)');
select healpix_nest(15, '(360d, -56.25d)');
select healpix_nest(15, '(360d, -50.625d)');
select healpix_ring(15, '(360d, -45d)');
select healpix_ring(15, '(360d, -39.375d)');
select healpix_ring(15, '(360d, -33.75d)');
select healpix_ring(15, '(360d, -28.125d)');
select healpix_ring(15, '(360d, -22.5d)');
select healpix_ring(15, '(360d, -16.875d)');
select healpix_ring(15, '(360d, -11.25d)');
select healpix_ring(15, '(360d, -5.625d)');
select healpix_ring(15, '(360d, 0.0001)');
select healpix_ring(15, '(360d, 5.625d)');
select healpix_nest(15, '(360d, 11.25d)');
select healpix_ring(15, '(360d, 16.875d)');
select healpix_nest(15, '(360d, 22.5d)');
select healpix_ring(15, '(360d, 28.125d)');
select healpix_nest(15, '(360d, 33.75d)');
select healpix_nest(15, '(360d, 39.375d)');
select healpix_ring(15, '(360d, 45d)');
select healpix_nest(15, '(360d, 50.625d)');
select healpix_nest(15, '(360d, 56.25d)');
select healpix_nest(15, '(360d, 61.875d)');
select healpix_ring(15, '(360d, 67.5d)');
select healpix_nest(15, '(360d, 73.125d)');
select healpix_nest(15, '(360d, 78.75d)');
select healpix_nest(15, '(360d, 84.375d)');
select healpix_nest(15, '(360d, 90d)');

select centre_of_healpix_ring(28, 537730339933102080);
select centre_of_healpix_nest(27, 201388984497553152);
select centre_of_healpix_nest(21, 44196118059124);
select centre_of_healpix_ring(27, 194581447837049088);
select centre_of_healpix_nest(13, 419722720);
select centre_of_healpix_nest(20, 6132786714249);
select centre_of_healpix_ring(20, 8227328938956);
select centre_of_healpix_nest(27, 54798618660893952);
select centre_of_healpix_nest(15, 6392603127);
select centre_of_healpix_ring(22, 115555464150489);
select centre_of_healpix_nest(26, 9823337059771008);
select centre_of_healpix_nest(24, 2278117826957604);
select centre_of_healpix_ring(12, 26680361);
select centre_of_healpix_ring(11, 9637138);
select centre_of_healpix_nest(14, 2792184976);
select centre_of_healpix_ring(4, 2732);
select centre_of_healpix_ring(24, 3110211681589728);
select centre_of_healpix_ring(4, 2307);
select centre_of_healpix_nest(5, 9269);
select centre_of_healpix_nest(21, 19605219971363);
select centre_of_healpix_ring(10, 2683217);
select centre_of_healpix_nest(23, 184729963468995);
select centre_of_healpix_nest(6, 3622);
select centre_of_healpix_nest(28, 534942473612104704);
select centre_of_healpix_ring(27, 146758529656356864);
select centre_of_healpix_ring(23, 382135742340279);
select centre_of_healpix_nest(27, 152634205458995712);
select centre_of_healpix_ring(28, 713459420104516608);
select centre_of_healpix_ring(8, 405421);
select centre_of_healpix_ring(6, 30504);
select centre_of_healpix_ring(7, 87548);
select centre_of_healpix_ring(13, 776006567);
select centre_of_healpix_ring(25, 12950711827228800);
select centre_of_healpix_ring(22, 111992516070519);
select centre_of_healpix_ring(20, 3830060322857);
select centre_of_healpix_ring(23, 184752358124289);
select centre_of_healpix_ring(14, 2747491487);
select centre_of_healpix_nest(28, 26976689329032192);
select centre_of_healpix_nest(10, 10982692);
select centre_of_healpix_ring(28, 861417470205514752);
select centre_of_healpix_nest(19, 1025023444235);
select centre_of_healpix_nest(14, 250621829);
select centre_of_healpix_nest(23, 518845461144234);
select centre_of_healpix_nest(25, 3407207856299664);
select centre_of_healpix_ring(24, 82744934806992);
select centre_of_healpix_nest(18, 136362875895);
select centre_of_healpix_ring(26, 29151516978609024);
select centre_of_healpix_nest(26, 41053381175033664);
select centre_of_healpix_ring(24, 1095683934718560);
select centre_of_healpix_nest(13, 704265631);
select centre_of_healpix_ring(14, 268093232);
select centre_of_healpix_nest(7, 146796);
select centre_of_healpix_nest(7, 178782);
select centre_of_healpix_ring(25, 469938201269808);
select centre_of_healpix_ring(17, 53330314920);
select centre_of_healpix_nest(16, 23042297401);
select centre_of_healpix_nest(8, 488194);
select centre_of_healpix_ring(20, 2248184383981);
select centre_of_healpix_nest(19, 842672017628);
select centre_of_healpix_nest(22, 170265834015278);
select centre_of_healpix_nest(21, 5910543280040);
select centre_of_healpix_nest(13, 184266675);
select centre_of_healpix_ring(14, 2667648192);
select centre_of_healpix_nest(22, 93236373840563);
select centre_of_healpix_nest(16, 34092166004);
select centre_of_healpix_nest(21, 12547642479303);
select centre_of_healpix_nest(14, 1920063540);
select centre_of_healpix_nest(18, 819693553060);
select centre_of_healpix_nest(5, 2787);
select centre_of_healpix_ring(28, 210546639978286080);
select centre_of_healpix_ring(20, 11287795966293);
select centre_of_healpix_nest(26, 1160601853988160);
select centre_of_healpix_ring(20, 7896584759340);
select centre_of_healpix_nest(8, 200830);
select centre_of_healpix_ring(17, 94199292826);
select centre_of_healpix_nest(6, 13985);
select centre_of_healpix_ring(11, 41386383);
select centre_of_healpix_ring(21, 35625085172533);
select centre_of_healpix_ring(10, 3660152);
select centre_of_healpix_ring(12, 141456730);
select centre_of_healpix_nest(13, 785134104);
select centre_of_healpix_nest(13, 724995839);
select centre_of_healpix_ring(23, 478718004930834);
select centre_of_healpix_nest(18, 700095158103);
select centre_of_healpix_nest(28, 537172777510268928);
select centre_of_healpix_ring(5, 1792);
select centre_of_healpix_nest(15, 3421616616);
select centre_of_healpix_ring(20, 10960258772104);
select centre_of_healpix_nest(16, 26152664735);
select centre_of_healpix_nest(6, 27586);
select centre_of_healpix_nest(14, 1130732644);
select centre_of_healpix_nest(8, 750730);
select centre_of_healpix_nest(11, 3757411);
select centre_of_healpix_ring(11, 5147858);
select centre_of_healpix_nest(9, 2517930);
select centre_of_healpix_nest(5, 1693);
select centre_of_healpix_nest(14, 1441523729);
select centre_of_healpix_nest(11, 17237236);
select centre_of_healpix_ring(8, 418930);
select centre_of_healpix_nest(24, 1668265634339076);
select centre_of_healpix_ring(7, 115506);
select centre_of_healpix_nest(22, 23361295754004);
select centre_of_healpix_nest(26, 27153318689347968);
select centre_of_healpix_nest(21, 29427698655517);
select centre_of_healpix_nest(9, 410791);
select centre_of_healpix_ring(25, 13499743064536176);
select centre_of_healpix_nest(8, 551129);
select centre_of_healpix_nest(21, 44016257494674);
select centre_of_healpix_nest(14, 207841802);
select centre_of_healpix_ring(12, 199193395);
select centre_of_healpix_ring(9, 1626029);
select centre_of_healpix_ring(20, 8358926913920);
select centre_of_healpix_nest(21, 14462892588205);
select centre_of_healpix_ring(28, 553448975120317440);
select centre_of_healpix_nest(27, 182451037576376832);
select centre_of_healpix_nest(25, 11258086296039696);
select centre_of_healpix_nest(12, 39036434);
select centre_of_healpix_nest(23, 32255266892451);
select centre_of_healpix_ring(10, 9398705);
select centre_of_healpix_nest(4, 1138);
select centre_of_healpix_ring(12, 77447327);
select centre_of_healpix_nest(15, 5690698366);
select centre_of_healpix_ring(23, 228379414182522);
select centre_of_healpix_ring(25, 13421573206491024);
select centre_of_healpix_nest(19, 3237029635046);
select centre_of_healpix_nest(23, 653047493772363);
select centre_of_healpix_ring(5, 8453);
select centre_of_healpix_nest(6, 17707);
select centre_of_healpix_ring(20, 3656306695019);
select centre_of_healpix_nest(23, 633776380932543);
select centre_of_healpix_ring(10, 10559717);
select centre_of_healpix_nest(27, 174358006860603648);
select centre_of_healpix_ring(7, 95598);
select centre_of_healpix_ring(25, 12720646885101360);
select centre_of_healpix_nest(17, 32055127047);
select centre_of_healpix_ring(19, 1507606380069);
select centre_of_healpix_ring(28, 164123870569021440);
select centre_of_healpix_nest(27, 172300653110093568);
select centre_of_healpix_ring(22, 6910463642626);
select centre_of_healpix_nest(26, 22492624630493760);
select centre_of_healpix_nest(25, 6659060140801344);
select centre_of_healpix_ring(20, 2203649323698);
select centre_of_healpix_nest(9, 2235150);
select centre_of_healpix_nest(11, 10617249);
select centre_of_healpix_ring(17, 64938630037);
select centre_of_healpix_ring(11, 40883797);
select centre_of_healpix_nest(12, 19282855);
select centre_of_healpix_nest(23, 623780293601457);
select centre_of_healpix_ring(9, 3072501);
select centre_of_healpix_ring(8, 307021);
select centre_of_healpix_nest(27, 151738271099917824);
select centre_of_healpix_ring(23, 538441050048837);
select centre_of_healpix_ring(8, 575044);
select centre_of_healpix_nest(6, 30763);
select centre_of_healpix_nest(17, 52812136219);
select centre_of_healpix_ring(22, 40208698630502);
select centre_of_healpix_ring(5, 8535);
select centre_of_healpix_ring(23, 232628212281579);
select centre_of_healpix_ring(7, 110204);
select centre_of_healpix_nest(13, 622800234);
select centre_of_healpix_ring(8, 585024);
select centre_of_healpix_ring(9, 2601756);
select centre_of_healpix_ring(13, 746326751);
select centre_of_healpix_nest(25, 1757052529154064);
select centre_of_healpix_nest(8, 32662);
select centre_of_healpix_ring(26, 117149321094336);
select centre_of_healpix_ring(26, 15298421910153600);
select centre_of_healpix_nest(14, 2518871769);
select centre_of_healpix_ring(17, 103077161842);
select centre_of_healpix_nest(27, 63784668416739072);
select centre_of_healpix_nest(18, 631098472239);
select centre_of_healpix_ring(13, 48600095);
select centre_of_healpix_nest(23, 400344733238772);
select centre_of_healpix_nest(10, 4023574);
select centre_of_healpix_ring(15, 12166851947);
select centre_of_healpix_ring(12, 35645541);
select centre_of_healpix_nest(25, 6029463767298432);
select centre_of_healpix_ring(23, 293379976031151);
select centre_of_healpix_nest(8, 425016);
select centre_of_healpix_ring(24, 1819410423699780);
select centre_of_healpix_ring(18, 248548350469);
select centre_of_healpix_ring(21, 21784662328254);
select centre_of_healpix_ring(24, 1919910867680472);
select centre_of_healpix_nest(11, 49569053);
select centre_of_healpix_ring(4, 2302);
select centre_of_healpix_ring(18, 755357167125);
select centre_of_healpix_nest(14, 2953072407);
select centre_of_healpix_nest(7, 120833);
select centre_of_healpix_nest(23, 412827339199236);
select centre_of_healpix_ring(22, 5521330266978);
select centre_of_healpix_nest(27, 168370330808286720);
select centre_of_healpix_nest(17, 83339807644);
select centre_of_healpix_nest(6, 9178);
select centre_of_healpix_nest(10, 499837);
select centre_of_healpix_nest(27, 114801840312943104);
select centre_of_healpix_ring(8, 359324);
select centre_of_healpix_nest(8, 243307);
select centre_of_healpix_ring(13, 331571919);
select centre_of_healpix_ring(4, 996);
select centre_of_healpix_nest(22, 152304766469933);
select centre_of_healpix_ring(23, 213842515389360);
select centre_of_healpix_ring(25, 7605691185820272);
select centre_of_healpix_ring(17, 17344372343);
select centre_of_healpix_ring(28, 552893874565555200);
select centre_of_healpix_ring(8, 163219);
select centre_of_healpix_nest(28, 856163252610493440);
select centre_of_healpix_ring(8, 673143);
select centre_of_healpix_nest(26, 48909027540191040);
select centre_of_healpix_ring(22, 64899608502222);
select centre_of_healpix_ring(9, 768037);
select centre_of_healpix_ring(21, 32654589766489);
select centre_of_healpix_nest(9, 1053660);
select centre_of_healpix_nest(13, 96616303);
select centre_of_healpix_nest(19, 575871286060);
select centre_of_healpix_ring(25, 2625975271359840);
select centre_of_healpix_ring(6, 21866);
select centre_of_healpix_nest(27, 108902701335429120);
select centre_of_healpix_nest(24, 1747788089627100);
select centre_of_healpix_nest(25, 9387397184945568);
select centre_of_healpix_nest(16, 21290390211);
select centre_of_healpix_ring(23, 602118262698276);
select centre_of_healpix_ring(22, 121019813893770);
select centre_of_healpix_ring(23, 670925558888478);
select centre_of_healpix_nest(8, 476579);
select centre_of_healpix_nest(21, 1296612819316);
select centre_of_healpix_nest(18, 744415163816);
select centre_of_healpix_ring(7, 158513);
select centre_of_healpix_nest(26, 8283332720144448);
select centre_of_healpix_nest(8, 443510);
select centre_of_healpix_ring(20, 10243296680507);
select centre_of_healpix_nest(14, 524948749);
select centre_of_healpix_nest(8, 268356);
select centre_of_healpix_ring(25, 9927317814361344);
select centre_of_healpix_nest(8, 420848);
select centre_of_healpix_nest(18, 91891787035);
select centre_of_healpix_nest(7, 190630);
select centre_of_healpix_ring(14, 700837772);
select centre_of_healpix_ring(16, 7300830501);
select centre_of_healpix_ring(6, 31387);
select centre_of_healpix_nest(12, 131514460);
select centre_of_healpix_nest(28, 724400904310972416);
select centre_of_healpix_nest(20, 6284135401219);
select centre_of_healpix_ring(21, 19581388019467);
select centre_of_healpix_ring(17, 40559382784);
select centre_of_healpix_ring(26, 16374282674949888);
select centre_of_healpix_ring(16, 21632474274);
select centre_of_healpix_nest(13, 151449648);
select centre_of_healpix_ring(17, 42728762216);
select centre_of_healpix_nest(28, 352305614184480768);
select centre_of_healpix_nest(21, 20095018204721);
select centre_of_healpix_ring(10, 11340177);
select centre_of_healpix_nest(26, 32893681947418176);
select centre_of_healpix_ring(15, 6287458078);
select centre_of_healpix_ring(23, 595068892059339);
select centre_of_healpix_ring(8, 554008);
select centre_of_healpix_ring(11, 24063730);
select centre_of_healpix_nest(27, 175949729925654528);
select centre_of_healpix_nest(25, 9751323561149424);
select centre_of_healpix_ring(22, 76010226825232);
select centre_of_healpix_ring(17, 192235443426);
select centre_of_healpix_nest(25, 13353203720119488);
select centre_of_healpix_nest(4, 188);
select centre_of_healpix_ring(17, 150113787375);
select centre_of_healpix_ring(28, 575022982193206272);
select centre_of_healpix_nest(23, 38337620048880);
select centre_of_healpix_nest(18, 105399907547);
select centre_of_healpix_ring(10, 3599087);
select centre_of_healpix_nest(17, 37005340465);
select centre_of_healpix_nest(25, 8529145197921600);
select centre_of_healpix_ring(8, 206512);
select centre_of_healpix_ring(4, 1640);
select centre_of_healpix_ring(24, 91000974883188);
select centre_of_healpix_ring(28, 655076657276510208);
select centre_of_healpix_nest(8, 354326);
select centre_of_healpix_ring(28, 437289273741232128);
select centre_of_healpix_nest(10, 1810016);
select centre_of_healpix_nest(16, 5043389430);
select centre_of_healpix_nest(20, 4890174394743);
select centre_of_healpix_ring(16, 7585288994);
select centre_of_healpix_nest(7, 35117);
select centre_of_healpix_nest(23, 469154380672512);
select centre_of_healpix_ring(21, 51124579290395);
select centre_of_healpix_nest(21, 43061741590241);
select centre_of_healpix_nest(6, 45011);
select centre_of_healpix_ring(10, 11818725);
select centre_of_healpix_nest(7, 82812);
select centre_of_healpix_nest(11, 2973688);
select centre_of_healpix_nest(26, 13177197635570496);
select centre_of_healpix_ring(7, 104005);
select centre_of_healpix_nest(13, 515003732);
select centre_of_healpix_ring(23, 616923614077794);
select centre_of_healpix_nest(12, 145580625);
select centre_of_healpix_nest(13, 221832964);
select centre_of_healpix_nest(27, 43743530156299008);
select centre_of_healpix_ring(6, 11149);
select centre_of_healpix_ring(24, 1986386821013076);
select centre_of_healpix_nest(22, 89030521328388);
select centre_of_healpix_nest(7, 104492);
select centre_of_healpix_ring(24, 1890512933187240);
select centre_of_healpix_ring(11, 42718289);
select centre_of_healpix_ring(11, 37314260);
select centre_of_healpix_ring(7, 16319);
select centre_of_healpix_ring(16, 17063806146);
select centre_of_healpix_nest(19, 482933093069);
select centre_of_healpix_nest(13, 17886230);
select centre_of_healpix_ring(14, 1659230217);
select centre_of_healpix_nest(23, 556582830569202);
select centre_of_healpix_nest(10, 9747713);
select centre_of_healpix_ring(27, 53474052047600640);
select centre_of_healpix_ring(9, 64472);
select centre_of_healpix_nest(28, 230638103844280320);
select centre_of_healpix_nest(26, 6737794664028480);
select centre_of_healpix_ring(27, 88027640762867712);
select centre_of_healpix_ring(11, 47786973);
select centre_of_healpix_nest(7, 69760);
select centre_of_healpix_nest(18, 63097617165);
select centre_of_healpix_nest(25, 6285710215264320);
select centre_of_healpix_ring(6, 13394);
select centre_of_healpix_ring(26, 22939779420643200);
select centre_of_healpix_ring(9, 266389);
select centre_of_healpix_nest(27, 122009553180272640);
select centre_of_healpix_nest(16, 24853447555);
select centre_of_healpix_ring(9, 2529982);
select centre_of_healpix_ring(17, 192098743383);
select centre_of_healpix_nest(5, 7854);
select centre_of_healpix_nest(18, 785919798058);
select centre_of_healpix_nest(8, 395617);
select centre_of_healpix_nest(6, 6044);
select centre_of_healpix_nest(21, 34513392528579);
select centre_of_healpix_nest(18, 148005059466);
select centre_of_healpix_nest(8, 715649);
select centre_of_healpix_nest(23, 351381100291209);
select centre_of_healpix_nest(25, 4783646356031808);
select centre_of_healpix_ring(22, 85496057792022);
select centre_of_healpix_nest(19, 1207760446960);
select centre_of_healpix_ring(12, 4537051);
select centre_of_healpix_ring(25, 10113085274651520);
select centre_of_healpix_ring(9, 59013);
select centre_of_healpix_ring(21, 18299648502817);
select centre_of_healpix_nest(25, 522136150124304);
select centre_of_healpix_ring(27, 58005231034801152);
select centre_of_healpix_ring(16, 21324213405);
select centre_of_healpix_ring(18, 681197524109);
select centre_of_healpix_nest(4, 2747);
select centre_of_healpix_ring(12, 63242546);
select centre_of_healpix_nest(23, 266330939391735);
select centre_of_healpix_nest(9, 2527310);
select centre_of_healpix_nest(6, 10625);
select centre_of_healpix_ring(12, 108698312);
select centre_of_healpix_ring(13, 448405209);
select centre_of_healpix_ring(28, 171484986911913984);
select centre_of_healpix_nest(9, 2931469);
select centre_of_healpix_nest(11, 48351965);
select centre_of_healpix_ring(9, 2852237);
select centre_of_healpix_ring(9, 2124465);
select centre_of_healpix_ring(20, 7920766156877);
select centre_of_healpix_ring(15, 9477540416);
select centre_of_healpix_ring(5, 5817);
select centre_of_healpix_ring(25, 364214521001568);
select centre_of_healpix_nest(9, 1500146);
select centre_of_healpix_nest(9, 318689);
select centre_of_healpix_nest(24, 3013812035436828);
select centre_of_healpix_ring(15, 8625053502);
select centre_of_healpix_nest(23, 301762129114665);
select centre_of_healpix_ring(14, 1360364144);
select centre_of_healpix_ring(21, 28831684353487);
select centre_of_healpix_nest(7, 104120);
select centre_of_healpix_ring(14, 2059339503);
select centre_of_healpix_nest(22, 24116353817334);
select centre_of_healpix_ring(8, 331229);
select centre_of_healpix_ring(5, 1301);
select centre_of_healpix_ring(6, 32102);
select centre_of_healpix_ring(12, 78593144);
select centre_of_healpix_nest(4, 1274);
select centre_of_healpix_nest(26, 2951121583832448);
select centre_of_healpix_ring(8, 177721);
select centre_of_healpix_ring(15, 5126307896);
select centre_of_healpix_nest(8, 336496);
select centre_of_healpix_ring(5, 1433);
select centre_of_healpix_nest(4, 2205);
select centre_of_healpix_ring(8, 433554);
select centre_of_healpix_nest(28, 763891381271079936);
select centre_of_healpix_nest(4, 552);
select centre_of_healpix_ring(16, 36844526833);
select centre_of_healpix_nest(28, 304600187742953472);
select centre_of_healpix_ring(4, 1070);
select centre_of_healpix_ring(14, 1439319910);
select centre_of_healpix_nest(26, 51738357988210752);
select centre_of_healpix_ring(24, 3357764546304816);
select centre_of_healpix_nest(14, 497728405);
select centre_of_healpix_nest(5, 153);
select centre_of_healpix_ring(15, 5946373304);
select centre_of_healpix_ring(28, 696282245114216448);
select centre_of_healpix_nest(10, 8775651);
select centre_of_healpix_ring(7, 33605);
select centre_of_healpix_nest(28, 546743161722971136);
select centre_of_healpix_ring(19, 1530804674464);
select centre_of_healpix_nest(5, 11024);
select centre_of_healpix_nest(18, 638767380106);
select centre_of_healpix_nest(18, 200627300011);
select centre_of_healpix_ring(24, 2465246686601184);
select centre_of_healpix_ring(16, 49149556174);
select centre_of_healpix_ring(7, 64840);
select centre_of_healpix_nest(18, 548367336389);
select centre_of_healpix_ring(15, 8439007258);
select centre_of_healpix_ring(10, 5853741);
select centre_of_healpix_nest(25, 11843978463310176);
select centre_of_healpix_ring(12, 127899067);
select centre_of_healpix_ring(10, 3447899);
select centre_of_healpix_ring(27, 105385457032640256);
select centre_of_healpix_ring(7, 56074);
select centre_of_healpix_nest(16, 6080447868);
select centre_of_healpix_nest(26, 9443360004995328);
select centre_of_healpix_ring(5, 7358);
select centre_of_healpix_nest(22, 83115008093623);
select centre_of_healpix_nest(22, 119661787861931);
select centre_of_healpix_ring(10, 1741511);
select centre_of_healpix_nest(28, 233601830524124160);
select centre_of_healpix_nest(26, 25542715168258176);
select centre_of_healpix_nest(25, 11683039506655248);
select centre_of_healpix_nest(9, 2703723);
select centre_of_healpix_ring(15, 2350431080);
select centre_of_healpix_nest(20, 2167291092838);
select centre_of_healpix_ring(25, 9924289250746704);
select centre_of_healpix_ring(7, 39352);
select centre_of_healpix_nest(6, 40574);
select centre_of_healpix_ring(8, 165301);
select centre_of_healpix_nest(12, 181533311);
select centre_of_healpix_ring(15, 3425067326);
select centre_of_healpix_nest(25, 1221534201635760);
select centre_of_healpix_ring(13, 507906418);
select centre_of_healpix_ring(23, 287308029832317);
select centre_of_healpix_ring(26, 53135871436457472);
select centre_of_healpix_nest(19, 1090670601536);
select centre_of_healpix_ring(20, 3867641411341);
select centre_of_healpix_ring(9, 2065273);
select centre_of_healpix_ring(12, 135779992);
select centre_of_healpix_ring(20, 10935521542147);
select centre_of_healpix_nest(19, 114949887864);
select centre_of_healpix_ring(5, 10883);
select centre_of_healpix_ring(9, 391580);
select centre_of_healpix_ring(26, 50284229585712576);
select centre_of_healpix_ring(8, 210966);
select centre_of_healpix_nest(6, 25485);
select centre_of_healpix_nest(16, 40277340625);
select centre_of_healpix_nest(27, 124500430430571264);
select centre_of_healpix_ring(4, 2050);
select centre_of_healpix_ring(15, 6278179983);
select centre_of_healpix_ring(21, 19865305926466);
select centre_of_healpix_ring(12, 42611685);
select centre_of_healpix_ring(8, 425777);
select centre_of_healpix_nest(5, 8088);
select centre_of_healpix_ring(9, 1394154);
select centre_of_healpix_ring(17, 70106593390);
select centre_of_healpix_nest(25, 7468662076615776);
select centre_of_healpix_nest(18, 308025039646);
select centre_of_healpix_nest(26, 49821874966440960);
select centre_of_healpix_ring(23, 322203559978023);
select centre_of_healpix_ring(22, 173896119291346);
select centre_of_healpix_ring(16, 693814171);
select centre_of_healpix_ring(13, 298804590);
select centre_of_healpix_nest(9, 896428);
select centre_of_healpix_ring(18, 182043356873);
select centre_of_healpix_ring(25, 12141108247773648);
select centre_of_healpix_nest(18, 706452677992);
select centre_of_healpix_ring(28, 10821196959267840);
select centre_of_healpix_nest(6, 42704);
select centre_of_healpix_nest(28, 83146726739002368);
select centre_of_healpix_ring(19, 1818721106330);
select centre_of_healpix_ring(21, 43567771002648);
select centre_of_healpix_ring(4, 285);
select centre_of_healpix_nest(12, 108829729);
select centre_of_healpix_ring(7, 121332);
select centre_of_healpix_nest(21, 13214198507927);
select centre_of_healpix_nest(18, 818459787178);
select centre_of_healpix_nest(15, 286984387);
select centre_of_healpix_ring(28, 330620058047385600);
select centre_of_healpix_nest(24, 2927095447682220);
select centre_of_healpix_nest(15, 5976562503);
select centre_of_healpix_nest(6, 47262);
select centre_of_healpix_nest(8, 706033);
select centre_of_healpix_ring(9, 439829);
select centre_of_healpix_ring(22, 105872067443080);
select centre_of_healpix_nest(22, 186380323353200);
select centre_of_healpix_ring(22, 18009694346571);
select centre_of_healpix_ring(24, 1849489461497676);
select centre_of_healpix_ring(26, 6448642685073792);
select centre_of_healpix_ring(15, 3626703168);
select centre_of_healpix_ring(5, 2626);
select centre_of_healpix_ring(11, 9697428);
select centre_of_healpix_ring(13, 711811032);
select centre_of_healpix_nest(25, 3493846776138384);
select centre_of_healpix_nest(28, 738579839670079488);
select centre_of_healpix_ring(19, 205996276047);
select centre_of_healpix_nest(8, 221921);
select centre_of_healpix_ring(28, 225046655046448128);
select centre_of_healpix_ring(26, 38756175364167168);
select centre_of_healpix_ring(5, 6369);
select centre_of_healpix_ring(15, 5622641090);
select centre_of_healpix_ring(13, 268460119);
select centre_of_healpix_nest(23, 386756705319996);
select centre_of_healpix_nest(24, 1868157948872844);
select centre_of_healpix_nest(16, 42113264243);
select centre_of_healpix_nest(8, 76545);
select centre_of_healpix_ring(20, 2286133036507);
select centre_of_healpix_ring(13, 600991966);
select centre_of_healpix_nest(16, 47302719492);
select centre_of_healpix_ring(16, 35315710213);
select centre_of_healpix_ring(11, 30531997);
select centre_of_healpix_ring(20, 9467064114415);
select centre_of_healpix_nest(8, 365891);
select centre_of_healpix_ring(20, 497243183126);
select centre_of_healpix_ring(12, 29572415);
select centre_of_healpix_nest(17, 123666065789);
select centre_of_healpix_nest(22, 174709815316048);
select centre_of_healpix_ring(18, 348731659907);
select centre_of_healpix_ring(23, 275824916311884);
select centre_of_healpix_nest(24, 2164146544751052);
select centre_of_healpix_ring(21, 16310692827216);
select centre_of_healpix_ring(28, 799536742754669568);
select centre_of_healpix_ring(27, 93052091697524736);
select centre_of_healpix_ring(19, 1091612438753);
select centre_of_healpix_nest(13, 8074557);
select centre_of_healpix_ring(9, 2819977);
select centre_of_healpix_ring(5, 10805);
select centre_of_healpix_nest(10, 5501413);
select centre_of_healpix_nest(26, 37392938530485120);
select centre_of_healpix_ring(14, 831021220);
select centre_of_healpix_nest(26, 31258268057869824);
select centre_of_healpix_nest(7, 57069);
select centre_of_healpix_ring(22, 101667031522612);
select centre_of_healpix_ring(18, 608913542939);
select centre_of_healpix_ring(6, 18471);
select centre_of_healpix_nest(21, 31527810935340);
select centre_of_healpix_ring(22, 92078063934181);
select centre_of_healpix_nest(13, 164187661);
select centre_of_healpix_nest(24, 279431807745024);
select centre_of_healpix_nest(28, 601827277442571264);
select centre_of_healpix_ring(5, 8219);
select centre_of_healpix_ring(10, 6154916);
select centre_of_healpix_nest(14, 695675771);
select centre_of_healpix_ring(22, 94858604681754);
select centre_of_healpix_nest(26, 22385669837084544);
select centre_of_healpix_nest(26, 19446327774759744);
select centre_of_healpix_ring(11, 12201331);
select centre_of_healpix_nest(17, 34462086549);
select centre_of_healpix_nest(11, 31630711);
select centre_of_healpix_nest(27, 113694813714710784);
select centre_of_healpix_nest(23, 667784128403820);
select centre_of_healpix_ring(11, 44687061);
select centre_of_healpix_ring(18, 274977429575);
select centre_of_healpix_nest(9, 2838773);
select centre_of_healpix_ring(5, 1710);
select centre_of_healpix_nest(6, 39938);
select centre_of_healpix_ring(13, 238449072);
select centre_of_healpix_nest(21, 23730825026814);
select centre_of_healpix_ring(19, 1796609073007);
select centre_of_healpix_ring(20, 6327661430434);
select centre_of_healpix_nest(7, 195671);
select centre_of_healpix_nest(14, 129747966);
select centre_of_healpix_ring(15, 4335858267);
select centre_of_healpix_ring(27, 131412997211631360);
select centre_of_healpix_nest(22, 81837808796668);
select centre_of_healpix_ring(25, 6572063630925072);
select centre_of_healpix_ring(12, 99696856);
select centre_of_healpix_ring(13, 185847849);
select centre_of_healpix_nest(14, 905417853);
select centre_of_healpix_nest(6, 22452);
select centre_of_healpix_ring(16, 49817464016);
select centre_of_healpix_ring(28, 393892648199740416);
select centre_of_healpix_ring(14, 754240326);
select centre_of_healpix_ring(24, 2816806896339684);
select centre_of_healpix_nest(25, 8832214882961472);
select centre_of_healpix_ring(14, 2251720605);
select centre_of_healpix_ring(27, 152665212339125760);
select centre_of_healpix_ring(13, 530729975);
select centre_of_healpix_nest(6, 37419);
select centre_of_healpix_nest(14, 2254665264);
select centre_of_healpix_nest(21, 31472886052600);
select centre_of_healpix_ring(14, 715531452);
select centre_of_healpix_ring(20, 6288770027214);
select centre_of_healpix_nest(11, 37491732);
select centre_of_healpix_ring(6, 27598);
select centre_of_healpix_nest(15, 10939572103);
select centre_of_healpix_ring(11, 16055639);
select centre_of_healpix_nest(24, 3284556376079004);
select centre_of_healpix_nest(5, 4359);
select centre_of_healpix_ring(10, 3378928);
select centre_of_healpix_nest(26, 27634141140706560);
select centre_of_healpix_ring(17, 10803296647);
select centre_of_healpix_nest(26, 23709435232142208);
select centre_of_healpix_nest(10, 1296378);
select centre_of_healpix_nest(19, 1575245828144);
select centre_of_healpix_nest(11, 2726999);
select centre_of_healpix_nest(24, 3099636690545736);
select centre_of_healpix_nest(15, 6264223126);
select centre_of_healpix_nest(24, 2619536815491696);
select centre_of_healpix_ring(18, 493881847077);
select centre_of_healpix_ring(6, 14889);
select centre_of_healpix_ring(21, 14870365099456);
select centre_of_healpix_ring(17, 18052950446);
select centre_of_healpix_ring(9, 3095970);
select centre_of_healpix_nest(27, 49656729287612928);
select centre_of_healpix_ring(16, 2535747372);
select centre_of_healpix_ring(13, 103964507);
select centre_of_healpix_ring(21, 27737721561370);
select centre_of_healpix_nest(21, 12512002615129);
select centre_of_healpix_nest(18, 165757354571);
select centre_of_healpix_nest(7, 146565);
select centre_of_healpix_ring(4, 2742);
select centre_of_healpix_ring(13, 320301716);
select centre_of_healpix_ring(17, 131409270184);
select centre_of_healpix_ring(14, 3094170600);
select centre_of_healpix_nest(27, 75391023158022912);
select centre_of_healpix_nest(11, 27166235);
select centre_of_healpix_ring(24, 565545348837204);
select centre_of_healpix_nest(25, 2126640087028992);
select centre_of_healpix_nest(25, 199961835361392);
select centre_of_healpix_ring(9, 559379);
select centre_of_healpix_ring(19, 2853546998659);
select centre_of_healpix_nest(16, 47315822096);
select centre_of_healpix_ring(22, 33960314204286);
select centre_of_healpix_ring(28, 5868928751941632);
select centre_of_healpix_ring(16, 1454567511);
select centre_of_healpix_nest(15, 9769337559);
select centre_of_healpix_nest(16, 1623946482);
select centre_of_healpix_nest(25, 12005065586729760);
select centre_of_healpix_nest(16, 49124069891);
select centre_of_healpix_nest(25, 2230922650209216);
select centre_of_healpix_ring(28, 342152606020439040);
select centre_of_healpix_ring(26, 52426357665414528);
select centre_of_healpix_nest(20, 5222772019166);
select centre_of_healpix_ring(27, 1751055573934080);
select centre_of_healpix_ring(24, 998003082512988);
select centre_of_healpix_ring(24, 2469632848212456);
select centre_of_healpix_nest(5, 5228);
select centre_of_healpix_nest(10, 9270552);
select centre_of_healpix_ring(22, 185551039603602);
select centre_of_healpix_ring(19, 13530914066);
select centre_of_healpix_nest(28, 597319441282249728);
select centre_of_healpix_nest(10, 5425090);
select centre_of_healpix_ring(15, 8121234206);
select centre_of_healpix_ring(27, 1168408328913408);
select centre_of_healpix_nest(16, 36161313850);
select centre_of_healpix_nest(24, 31553009213232);
select centre_of_healpix_ring(25, 3364032823619376);
select centre_of_healpix_nest(13, 113854346);
select centre_of_healpix_ring(12, 19181269);
select centre_of_healpix_ring(21, 49860077119959);
select centre_of_healpix_nest(5, 2942);
select centre_of_healpix_nest(24, 1057202692327464);
select centre_of_healpix_nest(23, 436114855314633);
select centre_of_healpix_ring(20, 1063390092871);
select centre_of_healpix_nest(16, 21420634573);
select centre_of_healpix_ring(10, 12110604);
select centre_of_healpix_nest(13, 346081569);
select centre_of_healpix_nest(19, 1183542884248);
select centre_of_healpix_nest(18, 683574460932);
select centre_of_healpix_ring(5, 6590);
select centre_of_healpix_nest(19, 420140468418);
select centre_of_healpix_ring(22, 207184398224823);
select centre_of_healpix_ring(23, 444693866890563);
select centre_of_healpix_ring(12, 8875280);
select centre_of_healpix_ring(11, 17715426);
select centre_of_healpix_nest(22, 20268640037856);
select centre_of_healpix_ring(21, 17615203451411);
select centre_of_healpix_ring(22, 36062207977702);
select centre_of_healpix_nest(18, 218572946343);
select centre_of_healpix_ring(15, 1434908109);
select centre_of_healpix_nest(13, 750839184);
select centre_of_healpix_nest(17, 198155809389);
select centre_of_healpix_nest(23, 113668850797485);
select centre_of_healpix_ring(13, 161765910);
select centre_of_healpix_ring(12, 129503779);
select centre_of_healpix_ring(20, 6226959808163);
select centre_of_healpix_ring(24, 2536325237566980);
select centre_of_healpix_nest(26, 5557614260288256);
select centre_of_healpix_nest(21, 46324118055801);
select centre_of_healpix_nest(4, 1057);
select centre_of_healpix_nest(6, 29624);
select centre_of_healpix_ring(16, 29183080758);
select centre_of_healpix_nest(27, 95935114026059520);
select centre_of_healpix_nest(16, 44182642748);
select centre_of_healpix_ring(23, 538679612339817);
select centre_of_healpix_nest(10, 5996383);
select centre_of_healpix_ring(21, 5758595135923);
select centre_of_healpix_ring(6, 19258);
select centre_of_healpix_ring(7, 119182);
select centre_of_healpix_ring(25, 125860990243200);
select centre_of_healpix_ring(21, 39057667543386);
select centre_of_healpix_nest(10, 919012);
select centre_of_healpix_nest(24, 2147335846674756);
select centre_of_healpix_nest(28, 822724412295081984);
select centre_of_healpix_nest(28, 225127735760489472);
select centre_of_healpix_ring(9, 2310825);
select centre_of_healpix_nest(17, 137170290591);
select centre_of_healpix_ring(26, 20422921971689472);
select centre_of_healpix_ring(5, 9545);
select centre_of_healpix_ring(6, 39409);
select centre_of_healpix_nest(27, 97747641148455168);
select centre_of_healpix_ring(12, 23639076);
select centre_of_healpix_ring(12, 156589092);
select centre_of_healpix_nest(10, 7898846);
select centre_of_healpix_nest(26, 8575286206583616);
select centre_of_healpix_ring(7, 50755);
select centre_of_healpix_nest(17, 198580473642);
select centre_of_healpix_ring(7, 126763);
select centre_of_healpix_ring(19, 1731132978273);
select centre_of_healpix_nest(15, 4727946330);
select centre_of_healpix_nest(8, 202866);
select centre_of_healpix_ring(5, 1684);
select centre_of_healpix_nest(6, 30592);
select centre_of_healpix_nest(17, 18895710150);
select centre_of_healpix_nest(16, 36556541);
select centre_of_healpix_nest(6, 37672);
select centre_of_healpix_ring(8, 334602);
select centre_of_healpix_ring(9, 1620472);
select centre_of_healpix_nest(18, 334249431051);
select centre_of_healpix_ring(4, 775);
select centre_of_healpix_ring(6, 19692);
select centre_of_healpix_ring(19, 1938502919617);
select centre_of_healpix_ring(27, 158155499442294528);
select centre_of_healpix_nest(24, 3156659896819272);
select centre_of_healpix_ring(15, 12868132370);
select centre_of_healpix_nest(9, 1297166);
select centre_of_healpix_nest(4, 1132);
select centre_of_healpix_ring(15, 9446349215);
select centre_of_healpix_nest(5, 269);
select centre_of_healpix_nest(26, 12978495580532736);
select centre_of_healpix_ring(10, 3320172);
select centre_of_healpix_nest(13, 183816574);
select centre_of_healpix_ring(11, 2159036);
select centre_of_healpix_ring(22, 15660794913993);
select centre_of_healpix_nest(26, 53218345157724864);
select centre_of_healpix_nest(24, 3214377331206264);
select centre_of_healpix_nest(17, 58757355986);
select centre_of_healpix_nest(6, 25793);
select centre_of_healpix_ring(22, 143504477729511);
select centre_of_healpix_ring(20, 4252777630460);
select centre_of_healpix_ring(8, 45524);
select centre_of_healpix_ring(21, 21991618730082);
select centre_of_healpix_nest(10, 5661014);
select centre_of_healpix_ring(9, 177472);
select centre_of_healpix_ring(23, 94151018134101);
select centre_of_healpix_nest(24, 3251841897559872);
select centre_of_healpix_nest(12, 22593063);
select centre_of_healpix_nest(16, 50581110835);
select centre_of_healpix_ring(26, 14476441975155264);
select centre_of_healpix_nest(23, 500109778740276);
select centre_of_healpix_ring(12, 28726413);
select centre_of_healpix_nest(12, 85695251);
select centre_of_healpix_nest(6, 37729);
select centre_of_healpix_ring(22, 145885972453206);
select centre_of_healpix_ring(17, 33609987894);
select centre_of_healpix_ring(27, 47656973132542464);
select centre_of_healpix_nest(25, 10560880425416976);
select centre_of_healpix_nest(11, 8655639);
select centre_of_healpix_ring(13, 607290142);
select centre_of_healpix_nest(28, 541123539656103936);
select centre_of_healpix_nest(6, 3386);
select centre_of_healpix_ring(13, 384622849);
select centre_of_healpix_nest(25, 7428787477467504);
select centre_of_healpix_ring(21, 26510317798031);
select centre_of_healpix_ring(27, 80940625510037760);
select centre_of_healpix_ring(8, 12430);
select centre_of_healpix_nest(4, 1604);
select centre_of_healpix_ring(24, 3127655356275960);
select centre_of_healpix_nest(26, 35903941340341056);
select centre_of_healpix_nest(23, 220156505312616);
select centre_of_healpix_ring(15, 6410546556);
select centre_of_healpix_ring(12, 70870934);
select centre_of_healpix_nest(18, 796344875135);
select centre_of_healpix_nest(26, 32943386695570176);
select centre_of_healpix_nest(24, 796828862563788);
select centre_of_healpix_nest(4, 2611);
select centre_of_healpix_nest(14, 1435532044);
select centre_of_healpix_ring(7, 54677);
select centre_of_healpix_ring(11, 37188057);
select centre_of_healpix_ring(18, 717699494335);
select centre_of_healpix_nest(17, 88295259690);
select centre_of_healpix_nest(26, 50295206460953856);
select centre_of_healpix_nest(13, 604197507);
select centre_of_healpix_ring(7, 53681);
select centre_of_healpix_nest(26, 29553050609915712);
select centre_of_healpix_nest(23, 573802897123704);
select centre_of_healpix_ring(16, 2916385746);
select centre_of_healpix_ring(28, 713181272405919744);
select centre_of_healpix_nest(9, 2802397);
select centre_of_healpix_ring(22, 111842661570519);
select centre_of_healpix_nest(10, 848225);
select centre_of_healpix_ring(17, 38106811811);
select centre_of_healpix_nest(14, 925009876);
select centre_of_healpix_nest(18, 156616712796);
select centre_of_healpix_nest(5, 1044);
select centre_of_healpix_ring(25, 3879154053677472);
select centre_of_healpix_ring(6, 9534);
select centre_of_healpix_ring(14, 1567279613);
select centre_of_healpix_nest(16, 28086844830);
select centre_of_healpix_nest(15, 5923434133);
select centre_of_healpix_nest(17, 157931199308);
select centre_of_healpix_nest(13, 730302836);
select centre_of_healpix_ring(20, 7843334530499);
select centre_of_healpix_nest(7, 33271);
select centre_of_healpix_ring(15, 8059818847);
select centre_of_healpix_nest(25, 2822353174832832);
select centre_of_healpix_ring(15, 7002952372);
select centre_of_healpix_ring(13, 621203432);
select centre_of_healpix_ring(14, 2077789940);
select centre_of_healpix_nest(15, 8709767142);
select centre_of_healpix_ring(21, 37201393479632);
select centre_of_healpix_ring(17, 100556860212);
select centre_of_healpix_ring(5, 6087);
select centre_of_healpix_nest(20, 9305529977729);
select centre_of_healpix_ring(28, 672180696943881216);
select centre_of_healpix_ring(8, 154370);
select centre_of_healpix_ring(27, 204140869291867392);
select centre_of_healpix_nest(23, 584838544598424);
select centre_of_healpix_ring(15, 5391830951);
select centre_of_healpix_nest(25, 10247294107160352);
select centre_of_healpix_ring(23, 433805540837073);
select centre_of_healpix_nest(8, 753337);
select centre_of_healpix_ring(12, 163316508);
select centre_of_healpix_nest(24, 132313761289944);
select centre_of_healpix_nest(11, 22447029);
select centre_of_healpix_nest(15, 328716562);
select centre_of_healpix_ring(8, 409496);
select centre_of_healpix_nest(25, 7923715822875552);
select centre_of_healpix_nest(13, 247418948);
select centre_of_healpix_nest(14, 1195779886);
select centre_of_healpix_nest(11, 27193973);
select centre_of_healpix_ring(19, 7947332529);
select centre_of_healpix_nest(5, 6451);
select centre_of_healpix_nest(10, 8181427);
select centre_of_healpix_nest(11, 14129363);
select centre_of_healpix_ring(22, 58668935737888);
select centre_of_healpix_nest(19, 2478922471255);
select centre_of_healpix_nest(16, 49343427381);
select centre_of_healpix_ring(23, 90087677211315);
select centre_of_healpix_ring(6, 61);
select centre_of_healpix_nest(7, 183325);
select centre_of_healpix_ring(10, 3956521);
select centre_of_healpix_nest(24, 1618756661694108);
select centre_of_healpix_ring(9, 471411);
select centre_of_healpix_nest(8, 81944);
select centre_of_healpix_nest(21, 50336408282729);
select centre_of_healpix_ring(7, 105426);
select centre_of_healpix_ring(8, 551619);
select centre_of_healpix_ring(6, 10826);
select centre_of_healpix_ring(19, 456144295505);
select centre_of_healpix_ring(8, 86919);
select centre_of_healpix_nest(12, 32821840);
select centre_of_healpix_nest(11, 10260771);
select centre_of_healpix_nest(15, 12140314131);
select centre_of_healpix_ring(15, 5585571293);
select centre_of_healpix_nest(6, 10998);
select centre_of_healpix_nest(23, 117828408342789);
select centre_of_healpix_ring(27, 59064740134010880);
select centre_of_healpix_nest(21, 33803177399951);
select centre_of_healpix_nest(24, 1826775614454120);
select centre_of_healpix_nest(28, 212880669794460672);
select centre_of_healpix_nest(15, 3359620743);
select centre_of_healpix_nest(19, 1127731680822);
select centre_of_healpix_nest(22, 89212640176039);
select centre_of_healpix_nest(12, 89747364);
select centre_of_healpix_ring(6, 10409);
select centre_of_healpix_nest(5, 11776);
select centre_of_healpix_nest(11, 8686187);
select centre_of_healpix_nest(10, 10876624);
select centre_of_healpix_nest(24, 1894683396160176);
select centre_of_healpix_nest(22, 182735075763924);
select centre_of_healpix_ring(23, 590933913725286);
select centre_of_healpix_ring(23, 104194933696725);
select centre_of_healpix_nest(6, 22093);
select centre_of_healpix_nest(14, 426353707);
select centre_of_healpix_ring(23, 697517322959850);
select centre_of_healpix_ring(6, 20934);
select centre_of_healpix_ring(22, 162988335867693);
select centre_of_healpix_nest(21, 18903077968495);
select centre_of_healpix_ring(4, 1433);
select centre_of_healpix_nest(26, 4534086012358464);
select centre_of_healpix_ring(20, 2044035672759);
select centre_of_healpix_nest(4, 2374);
select centre_of_healpix_ring(24, 1742464464305352);
select centre_of_healpix_ring(4, 1875);
select centre_of_healpix_nest(20, 6380933467350);
select centre_of_healpix_nest(21, 47966645501850);
select centre_of_healpix_nest(16, 5566476229);
select centre_of_healpix_nest(15, 11667645314);
select centre_of_healpix_ring(28, 260837993758162944);
select centre_of_healpix_ring(7, 42769);
select centre_of_healpix_ring(16, 40700063880);
select centre_of_healpix_nest(19, 1506495333618);
select centre_of_healpix_nest(17, 175826983607);
select centre_of_healpix_nest(27, 108957779962841856);
select centre_of_healpix_nest(23, 540667416984510);
select centre_of_healpix_nest(23, 137825919779085);
select centre_of_healpix_nest(4, 1097);
select centre_of_healpix_ring(10, 11095051);
select centre_of_healpix_nest(26, 10898162737721472);
select centre_of_healpix_ring(24, 525708146363268);
select centre_of_healpix_nest(25, 7869751756360896);
select centre_of_healpix_nest(26, 32666533368757440);
select centre_of_healpix_nest(24, 630079962106392);
select centre_of_healpix_ring(22, 73518473039645);
select centre_of_healpix_nest(7, 21748);
select centre_of_healpix_nest(27, 209387279675877120);
select centre_of_healpix_ring(16, 43658314709);
select centre_of_healpix_nest(20, 12244529311815);
select centre_of_healpix_ring(8, 232218);
select centre_of_healpix_nest(14, 3101754484);
select centre_of_healpix_nest(9, 2876664);
select centre_of_healpix_nest(11, 14885587);
select centre_of_healpix_nest(9, 1715953);
select centre_of_healpix_ring(13, 239458991);
select centre_of_healpix_nest(21, 27799228047781);
select centre_of_healpix_ring(4, 1082);
select centre_of_healpix_nest(13, 611734915);
select centre_of_healpix_ring(6, 15137);
select centre_of_healpix_nest(21, 10705018741137);
select centre_of_healpix_ring(23, 359597207691333);
select centre_of_healpix_ring(10, 10645781);
select centre_of_healpix_nest(20, 3923787457880);
select centre_of_healpix_nest(5, 11063);
select centre_of_healpix_ring(7, 99385);
select centre_of_healpix_ring(13, 715189606);
select centre_of_healpix_nest(4, 1659);
select centre_of_healpix_nest(23, 433381862541534);
select centre_of_healpix_nest(15, 12381569215);
select centre_of_healpix_ring(28, 545178676896473088);
select centre_of_healpix_ring(19, 721948443643);
select centre_of_healpix_nest(25, 11785044488625696);
select centre_of_healpix_ring(5, 3026);
select centre_of_healpix_nest(4, 755);
select centre_of_healpix_nest(4, 1006);
select centre_of_healpix_ring(8, 589428);
select centre_of_healpix_nest(8, 476910);
select centre_of_healpix_nest(26, 20215913898550272);
select centre_of_healpix_ring(8, 263230);
select centre_of_healpix_nest(26, 23224023091153536);
select centre_of_healpix_nest(4, 2775);
select centre_of_healpix_nest(21, 50855213552015);
select centre_of_healpix_nest(16, 22739550370);
select centre_of_healpix_nest(21, 41537481248278);
select centre_of_healpix_ring(13, 786405969);
select centre_of_healpix_ring(6, 33657);
select centre_of_healpix_ring(25, 4747485722356464);
select centre_of_healpix_nest(12, 45443918);
select centre_of_healpix_nest(18, 442269984503);
select centre_of_healpix_nest(20, 5883419355687);
select centre_of_healpix_ring(24, 2889283911166860);
select centre_of_healpix_ring(5, 4263);
select centre_of_healpix_ring(7, 60803);
select centre_of_healpix_ring(7, 126414);
select centre_of_healpix_ring(15, 5240814494);
select centre_of_healpix_nest(15, 4679860430);
select centre_of_healpix_ring(24, 2724511556131044);
select centre_of_healpix_ring(12, 24290244);
select centre_of_healpix_nest(23, 443737179389067);
select centre_of_healpix_nest(16, 24595100522);
select centre_of_healpix_ring(12, 150216911);
select centre_of_healpix_nest(17, 166706256311);
select centre_of_healpix_ring(19, 3012569586741);
select centre_of_healpix_nest(5, 1184);
select centre_of_healpix_ring(10, 4281154);
select centre_of_healpix_ring(13, 524180690);
select centre_of_healpix_nest(6, 42972);
select centre_of_healpix_ring(21, 30787249416012);
select centre_of_healpix_nest(27, 141057070214657280);
select centre_of_healpix_nest(10, 9233852);
select centre_of_healpix_nest(16, 5349298807);
select centre_of_healpix_nest(26, 27966244521661056);
select centre_of_healpix_nest(25, 3637003355050128);
select centre_of_healpix_nest(28, 495823041389678592);
select centre_of_healpix_ring(5, 4310);
select centre_of_healpix_ring(9, 711781);
select centre_of_healpix_ring(16, 6353025132);
select centre_of_healpix_ring(27, 194339818944215040);
select centre_of_healpix_nest(11, 22810257);
select centre_of_healpix_nest(22, 156788698513444);
select centre_of_healpix_nest(12, 84681028);
select centre_of_healpix_ring(22, 41816477699847);
select centre_of_healpix_nest(7, 191852);
select centre_of_healpix_nest(21, 40736166015669);
select centre_of_healpix_ring(8, 751918);
select centre_of_healpix_ring(27, 197271692919226368);
select centre_of_healpix_nest(26, 10155744003415488);
select centre_of_healpix_nest(10, 8220217);
select centre_of_healpix_nest(18, 303100606235);
select centre_of_healpix_nest(24, 2785698734739600);
select centre_of_healpix_nest(15, 7220087672);
select centre_of_healpix_nest(27, 95141763424132608);
select centre_of_healpix_ring(6, 48255);
select centre_of_healpix_ring(23, 491080541059656);
select centre_of_healpix_nest(20, 11176720369538);
select centre_of_healpix_ring(23, 741909774374946);
select centre_of_healpix_ring(22, 57419407468784);
select centre_of_healpix_nest(8, 704709);
select centre_of_healpix_nest(19, 893781667229);
select centre_of_healpix_ring(12, 71752063);
select centre_of_healpix_nest(16, 36831449562);
select centre_of_healpix_nest(8, 55238);
select centre_of_healpix_ring(15, 4319593095);
select centre_of_healpix_ring(13, 352692945);
select centre_of_healpix_nest(28, 116686047875343360);
select centre_of_healpix_nest(10, 7721095);
select centre_of_healpix_ring(6, 20913);
select centre_of_healpix_nest(17, 176710528483);
select centre_of_healpix_ring(11, 41896412);
select centre_of_healpix_nest(25, 11056931037767040);
select centre_of_healpix_nest(27, 21050182967750400);
select centre_of_healpix_nest(11, 13996192);
select centre_of_healpix_ring(16, 37213909794);
select centre_of_healpix_nest(8, 624154);
select centre_of_healpix_nest(20, 10928438563696);
select centre_of_healpix_nest(13, 439438363);
select centre_of_healpix_nest(23, 4300717187877);
select centre_of_healpix_ring(23, 159114204510432);
select centre_of_healpix_nest(10, 12068875);
select centre_of_healpix_nest(26, 46385801361653376);
select centre_of_healpix_nest(20, 723689301477);
select centre_of_healpix_nest(27, 72600036203185152);
select centre_of_healpix_ring(28, 519031082337119232);
select centre_of_healpix_nest(24, 1452520726872312);
select centre_of_healpix_ring(7, 14867);
select centre_of_healpix_ring(12, 191787536);
select centre_of_healpix_nest(9, 2530133);
select centre_of_healpix_ring(21, 49860599721652);
select centre_of_healpix_nest(27, 205171330321572096);
select centre_of_healpix_ring(26, 33220039743394560);
select centre_of_healpix_ring(9, 1015262);
select centre_of_healpix_ring(7, 178213);
select centre_of_healpix_nest(20, 7184631071659);
select centre_of_healpix_ring(26, 38703172787616768);
select centre_of_healpix_nest(8, 480072);
select centre_of_healpix_ring(22, 185067465977314);
select centre_of_healpix_nest(13, 515966125);
select centre_of_healpix_nest(14, 1246677573);
select centre_of_healpix_nest(11, 20023987);
select centre_of_healpix_nest(12, 75575650);
select centre_of_healpix_ring(5, 8969);
select centre_of_healpix_ring(23, 170547538414200);
select centre_of_healpix_nest(6, 21202);
select centre_of_healpix_ring(26, 41344020049933440);
select centre_of_healpix_ring(15, 880827815);
select centre_of_healpix_ring(14, 1398400204);
select centre_of_healpix_ring(13, 667594394);
select centre_of_healpix_ring(19, 2955926820093);
select centre_of_healpix_nest(16, 44426836500);
select centre_of_healpix_nest(16, 51295516247);
select centre_of_healpix_nest(18, 577743854748);
select centre_of_healpix_ring(12, 75117969);
select centre_of_healpix_ring(9, 2765628);
select centre_of_healpix_nest(19, 419893029776);
select centre_of_healpix_ring(9, 461229);
select centre_of_healpix_ring(21, 26237298069973);
select centre_of_healpix_nest(13, 585099177);
select centre_of_healpix_ring(28, 745902712931622912);
select centre_of_healpix_nest(19, 2425745544581);
select centre_of_healpix_nest(17, 167545986422);
select centre_of_healpix_nest(9, 2167450);
select centre_of_healpix_nest(20, 5524610276077);
select centre_of_healpix_ring(19, 3108844000319);
select centre_of_healpix_nest(6, 27800);
select centre_of_healpix_nest(27, 64863365879469312);
select centre_of_healpix_nest(9, 380480);
select centre_of_healpix_nest(20, 7179614470088);
select centre_of_healpix_nest(24, 2252994948242088);
select centre_of_healpix_ring(27, 121984399434180864);
select centre_of_healpix_ring(14, 1343000756);
select centre_of_healpix_ring(13, 350114120);
select centre_of_healpix_ring(11, 6980524);
select centre_of_healpix_nest(5, 1336);
select centre_of_healpix_ring(5, 9037);
select centre_of_healpix_nest(28, 849774482713525248);
select centre_of_healpix_nest(4, 2221);
select centre_of_healpix_nest(24, 320364357078852);
select centre_of_healpix_nest(15, 9112365641);
select centre_of_healpix_nest(8, 520786);
select centre_of_healpix_nest(24, 3081263809215192);
select centre_of_healpix_nest(26, 43803863391312192);
select centre_of_healpix_ring(8, 687400);
select centre_of_healpix_nest(26, 52219904624154048);
select centre_of_healpix_ring(7, 31551);
select centre_of_healpix_nest(15, 10308012275);
select centre_of_healpix_ring(22, 194616343973793);
select centre_of_healpix_nest(11, 15195578);
select centre_of_healpix_ring(11, 18602747);
select centre_of_healpix_ring(4, 2235);
select centre_of_healpix_nest(5, 6590);
select centre_of_healpix_nest(18, 678177580256);
select centre_of_healpix_nest(17, 165747513538);
select centre_of_healpix_nest(8, 747464);
select centre_of_healpix_ring(24, 2546103820703280);
select centre_of_healpix_nest(21, 37918915769211);
select centre_of_healpix_nest(16, 31646135441);
select centre_of_healpix_ring(28, 656590948524413952);
select centre_of_healpix_ring(19, 2018901411087);
select centre_of_healpix_ring(16, 50083935998);
select centre_of_healpix_ring(4, 2755);
select centre_of_healpix_ring(11, 9976702);
select centre_of_healpix_ring(16, 32927310045);
select centre_of_healpix_nest(11, 34556490);
select centre_of_healpix_ring(21, 13836070822576);
select centre_of_healpix_nest(1, 13);
select centre_of_healpix_nest(2, 57);
select centre_of_healpix_nest(1, 44);
select centre_of_healpix_nest(2, 154);
select centre_of_healpix_ring(2, 131);
select centre_of_healpix_ring(2, 136);
select centre_of_healpix_ring(3, 214);
select centre_of_healpix_ring(1, 5);
select centre_of_healpix_ring(2, 39);
select centre_of_healpix_nest(0, 3);
select centre_of_healpix_ring(1, 10);
select centre_of_healpix_ring(1, 3);
select centre_of_healpix_ring(3, 422);
select centre_of_healpix_nest(3, 260);
select centre_of_healpix_ring(1, 33);
select centre_of_healpix_nest(2, 69);
select centre_of_healpix_nest(0, 8);
select centre_of_healpix_ring(1, 2);
select centre_of_healpix_nest(3, 648);
select centre_of_healpix_ring(2, 95);
select centre_of_healpix_ring(2, 184);
select centre_of_healpix_ring(3, 510);
select centre_of_healpix_nest(1, 10);

select nside2order(-1);
select nside2order(-2);
select nside2order(0);
select nside2order(-15);
select nside2order(3);
select nside2order(5);
select nside2order(7);
select nside2order(9);
select nside2order(15);
select nside2order(17);
select nside2order(31);
select nside2order(65);
select nside2order(129);
select nside2order(255);
select nside2order(519);
select nside2order(1022);
select nside2order(2049);
select nside2order(4095);
select nside2order(8191);
select nside2order(16387);
select nside2order(32767);
select nside2order(65535);
select nside2order(131071);
select nside2order(262145);
select nside2order(524289);
select nside2order(1048546);
select nside2order(2093151);
select nside2order(4194303);
select nside2order(8388609);
select nside2order(16777217);
select nside2order(33554430);
select nside2order(67108860);
select nside2order(134217722);
select nside2order(268435457);
select nside2order(536870911);
select order2nside(-1);
select order2nside(30);
select order2nside(31);
select order2nside(-29);
select nside2npix(-1);
select nside2npix(3);
select nside2npix(5);
select nside2npix(11);
select nside2npix(17);
select nside2npix(33);
select nside2npix(63);
select nside2npix(129);
select nside2npix(257);
select nside2npix(511);
select nside2npix(1023);
select nside2npix(2049);
select nside2npix(4097);
select nside2npix(8191);
select nside2npix(16383);
select nside2npix(32769);
select nside2npix(65535);
select nside2npix(131071);
select nside2npix(262104);
select nside2npix(524208);
select nside2npix(1048076);
select nside2npix(2097052);
select nside2npix(4194301);
select nside2npix(8388607);
select nside2npix(16777217);
select nside2npix(33554431);
select nside2npix(67108865);
select nside2npix(134217727);
select nside2npix(268430456);
select nside2npix(536870913);
select npix2nside(-12);
select npix2nside(49);
select npix2nside(-2192);
select npix2nside(767);
select npix2nside(3071);
select npix2nside(12280);
select npix2nside(49150);
select npix2nside(196607);
select npix2nside(786431);
select npix2nside(3145723);
select npix2nside(12582911);
select npix2nside(50331647);
select npix2nside(201326591);
select npix2nside(805306369);
select npix2nside(3221225473);
select npix2nside(12884901808);
select npix2nside(51539607551);
select npix2nside(206158430209);
select npix2nside(824633720831);
select npix2nside(3298534883327);
select npix2nside(13194139533311);
select npix2nside(52776558133247);
select npix2nside(211106232532991);
select npix2nside(844424930131969);
select npix2nside(3377699720527873);
select npix2nside(13510798882111487);
select npix2nside(54043195528445951);
select npix2nside(216172782113783807);
select npix2nside(864691128455135231);
select npix2nside(3458764513820540929);

select centre_of_healpix_ring(1, 18471);
select centre_of_healpix_nest(6, -0);
select centre_of_healpix_ring(6, -1);
select centre_of_healpix_nest(6, -49151);
select centre_of_healpix_ring(6, 49151);
select centre_of_healpix_ring(6, 49152);
select centre_of_healpix_nest(6, 49153);

-- examples taken from Figure 4 of Healpix article (page 764)
select healpix_convert_nest(1, 2, 111);
select healpix_convert_nest(1, 2, 91);
select healpix_convert_nest(2, 1, 31);
select healpix_convert_nest(1, 2, 123);
select healpix_convert_ring(1, 2, 123);
select healpix_convert_nest(1, 2, 124);
select healpix_convert_nest(1, 2, 122);
select healpix_convert_ring(1, 2, 122);
select healpix_convert_ring(2, 1, 46);
select healpix_convert_nest(2, 1, 46);
select healpix_convert_ring(2, 1, 42);
select nest2ring(1, 11);
select nest2ring(1, 19);
select nest2ring(2, 87);
select nest2ring(2, 177);
select nest2ring(2, 0);
select ring2nest(1, 21);
select ring2nest(1, 3);
select ring2nest(1, 17);
select ring2nest(2, 117);
select ring2nest(2, 103);
select ring2nest(2, 186);
